@@ -27,7 +27,7 @@
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <X11/Xutil.h>
-#include "../config.h"
+#include "gldi-config.h"
 #ifdef HAVE_XEXTEND
 #include <X11/extensions/Xcomposite.h>
 //#include <X11/extensions/Xdamage.h>
@@ -36,6 +36,7 @@
 #include <X11/extensions/shape.h>
 #endif
 
+#include "cairo-dock-container.h"  // CAIRO_DOCK_HORIZONTAL
 #include "cairo-dock-log.h"
 #include "cairo-dock-X-manager.h"
 #include "cairo-dock-X-utilities.h"
@@ -173,7 +174,7 @@ gboolean cairo_dock_update_screen_geometry (void)
 		g_desktopGeometry.iScreenWidth[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL];
 		g_desktopGeometry.iScreenHeight[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL];  // si on utilise Xinerama, on mettra les valeurs correctes plus tard.
 		
-		cd_message ("new screen size : %dx%d\n", g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL], g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+		cd_debug ("new screen size : %dx%d", g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL], g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL]);
 		return TRUE;
 	}
 	else
