@@ -22,7 +22,7 @@
 #include <stdlib.h>
 #include <cairo.h>
 
-#include "cairo-dock-load.h"
+#include "cairo-dock-image-buffer.h"
 #include "cairo-dock-draw.h"
 #include "cairo-dock-config.h"
 #include "cairo-dock-launcher-manager.h"
@@ -36,12 +36,12 @@
 #include "cairo-dock-callbacks.h"
 #include "cairo-dock-dock-manager.h"
 #include "cairo-dock-draw-opengl.h"
-#include "cairo-dock-icons.h"
+#include "cairo-dock-icon-factory.h"
 #include "cairo-dock-container.h"
 #include "cairo-dock-gui-manager.h"
-#include "cairo-dock-internal-icons.h"
 #include "cairo-dock-backends-manager.h"
 #include "cairo-dock-dock-facility.h"
+#include "cairo-dock-icon-facility.h"
 #include "cairo-dock-applet-facility.h"
 
 extern gchar *g_cExtrasDirPath;
@@ -61,7 +61,7 @@ void cairo_dock_set_icon_surface_full (cairo_t *pIconContext, cairo_surface_t *p
 	if (pIcon != NULL &&
 		pIcon->pIconBuffer != NULL &&
 		g_pIconBackgroundBuffer.pSurface != NULL &&
-		(! CAIRO_DOCK_IS_SEPARATOR (pIcon)))
+		(! CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon)))
 	{
 		//cd_message (">>> %s prendra un fond d'icone", pIcon->cName);
 		cairo_save (pIconContext);
@@ -115,6 +115,18 @@ void cairo_dock_set_icon_surface_with_reflect (cairo_t *pIconContext, cairo_surf
 	cairo_dock_add_reflection_to_icon (pIcon, pContainer);
 }
 
+static inline void _set_image_on_icon (cairo_t *pIconContext, const gchar *cImagePath, Icon *pIcon, CairoContainer *pContainer)
+{
+	int iWidth, iHeight;
+	cairo_dock_get_icon_extent (pIcon, pContainer, &iWidth, &iHeight);
+	cairo_surface_t *pImageSurface = cairo_dock_create_surface_from_icon (cImagePath,
+		iWidth,
+		iHeight);
+	
+	cairo_dock_set_icon_surface_with_reflect (pIconContext, pImageSurface, pIcon, pContainer);
+	
+	cairo_surface_destroy (pImageSurface);
+}
 void cairo_dock_set_image_on_icon (cairo_t *pIconContext, const gchar *cImagePath, Icon *pIcon, CairoContainer *pContainer)
 {
 	if (cImagePath != pIcon->cFileName)
@@ -122,15 +134,34 @@ void cairo_dock_set_image_on_icon (cairo_t *pIconContext, const gchar *cImagePat
 		g_free (pIcon->cFileName);
 		pIcon->cFileName = g_strdup (cImagePath);
 	}
-	int iWidth, iHeight;
-	cairo_dock_get_icon_extent (pIcon, pContainer, &iWidth, &iHeight);
-	cairo_surface_t *pImageSurface = cairo_dock_create_surface_for_icon (cImagePath,
-		iWidth,
-		iHeight);
+	_set_image_on_icon (pIconContext, cImagePath, pIcon, pContainer);
+}
+
+void cairo_dock_set_image_on_icon_with_default (cairo_t *pIconContext, const gchar *cImage, Icon *pIcon, CairoContainer *pContainer, const gchar *cDefaultImagePath)
+{
+	if (cImage != pIcon->cFileName)
+	{
+		g_free (pIcon->cFileName);
+		pIcon->cFileName = g_strdup (cImage);
+	}
 	
-	cairo_dock_set_icon_surface_with_reflect (pIconContext, pImageSurface, pIcon, pContainer);
+	gchar *cFoundImage = NULL;
+	if (cImage != NULL)
+	{
+		if (*cImage == '/' || *cImage == '~')  // chemin, on se contente de verifier son existence.
+		{
+			cFoundImage = cairo_dock_search_image_s_path (cImage);
+		}
+		else  // nom d'image ou d'icone, on cherche.
+		{
+			cFoundImage = cairo_dock_search_icon_s_path (cImage);  // on cherche en priorite une icone.
+			if (cFoundImage == NULL)  // si aucune icone, on regarde dans les repertoires d'images.
+				cFoundImage = cairo_dock_search_image_s_path (cImage);
+		}
+	}
 	
-	cairo_surface_destroy (pImageSurface);
+	_set_image_on_icon (pIconContext, cFoundImage ? cFoundImage : cDefaultImagePath, pIcon, pContainer);
+	g_free (cFoundImage);
 }
 
 void cairo_dock_set_icon_surface_with_bar (cairo_t *pIconContext, cairo_surface_t *pSurface, double fValue, Icon *pIcon)
@@ -319,21 +350,23 @@ void cairo_dock_play_sound (const gchar *cSoundPath)
 	
 	GError *erreur = NULL;
 	gchar *cSoundCommand = NULL;
-	if (g_file_test ("/usr/bin/play", G_FILE_TEST_EXISTS))
-		cSoundCommand = g_strdup_printf("play \"%s\"", cSoundPath);
-		
+	if (g_file_test ("/usr/bin/paplay", G_FILE_TEST_EXISTS))
+		cSoundCommand = g_strdup_printf("paplay --client-name=cairo-dock \"%s\"", cSoundPath);
+
 	else if (g_file_test ("/usr/bin/aplay", G_FILE_TEST_EXISTS))
 		cSoundCommand = g_strdup_printf("aplay \"%s\"", cSoundPath);
+
+	else if (g_file_test ("/usr/bin/play", G_FILE_TEST_EXISTS))
+		cSoundCommand = g_strdup_printf("play \"%s\"", cSoundPath);
 	
-	else if (g_file_test ("/usr/bin/paplay", G_FILE_TEST_EXISTS))
-		cSoundCommand = g_strdup_printf("paplay \"%s\"", cSoundPath);
 	
 	cairo_dock_launch_command (cSoundCommand);
 	
 	g_free (cSoundCommand);
 }
 
-void cairo_dock_get_gnome_version (int *iMajor, int *iMinor, int *iMicro) {
+// should be in gnome-integration if needed...
+/*void cairo_dock_get_gnome_version (int *iMajor, int *iMinor, int *iMicro) {
 	gchar *cContent = NULL;
 	gsize length = 0;
 	GError *erreur = NULL;
@@ -409,7 +442,7 @@ void cairo_dock_get_gnome_version (int *iMajor, int *iMinor, int *iMicro) {
 	
 	g_free (cContent);
 	g_strfreev (cLineList);
-}
+}*/
 
 void cairo_dock_pop_up_about_applet (GtkMenuItem *menu_item, CairoDockModuleInstance *pModuleInstance)
 {
@@ -597,3 +630,42 @@ void cairo_dock_remove_all_icons_from_applet (CairoDockModuleInstance *pInstance
 		}
 	}
 }
+
+
+
+void cairo_dock_resize_applet (CairoDockModuleInstance *pInstance, int w, int h)
+{
+	Icon *pIcon = pInstance->pIcon;
+	g_return_if_fail (pIcon != NULL);
+	
+	CairoContainer *pContainer = pInstance->pContainer;
+	g_return_if_fail (pContainer != NULL);
+	
+	if (pInstance->pDock)
+	{
+		double fMaxScale = cairo_dock_get_max_scale (pContainer);
+		pIcon->fWidth = w / fMaxScale;
+		pIcon->fHeight = h / fMaxScale;  // set the height too, because at the moment it takes into account the dock's ratio.
+		pIcon->iImageWidth = 0;  // will be updated when the icon is reloaded.
+		pIcon->iImageHeight = 0;  // will be updated when the icon is reloaded.
+		cairo_dock_load_icon_image (pIcon, pContainer);
+		
+		if (pInstance->pDrawContext)
+		{
+			cairo_destroy (pInstance->pDrawContext);
+			pInstance->pDrawContext = NULL;
+		}
+		if (pIcon->pIconBuffer)
+			pInstance->pDrawContext = cairo_create (pIcon->pIconBuffer);
+		if (cairo_status (pInstance->pDrawContext) != CAIRO_STATUS_SUCCESS)
+			pInstance->pDrawContext = NULL;
+		
+		cairo_dock_update_dock_size (pInstance->pDock);
+	}
+	else  // in desklet mode, just resize the desklet, it will trigger the reload of the applet when the 'configure' event is received.
+	{
+		gtk_window_resize (GTK_WINDOW (pContainer->pWidget),
+			w,
+			h);
+	}
+}
