@@ -32,25 +32,35 @@
 #include <gtk/gtkgl.h>
 #include <GL/gl.h> 
 
-#include "cairo-dock-icons.h"
-#include "cairo-dock-dock-factory.h"
-#include "cairo-dock-dock-facility.h"
-#include "cairo-dock-dock-manager.h"
+#include "cairo-dock-icon-facility.h"  // cairo_dock_compute_icon_area
+#include "cairo-dock-dock-facility.h"  // cairo_dock_is_hidden
+#include "cairo-dock-module-factory.h"  // cairo_dock_search_container_from_icon
+#include "cairo-dock-dock-manager.h"  // cairo_dock_search_dock_from_name
+#include "cairo-dock-desklet-factory.h"  // cairo_dock_search_container_from_icon
 #include "cairo-dock-log.h"
+#include "cairo-dock-config.h"
 #include "cairo-dock-opengl.h"
 #include "cairo-dock-notifications.h"
-#include "cairo-dock-animations.h"
-#include "cairo-dock-callbacks.h"
-#include "cairo-dock-X-manager.h"
+#include "cairo-dock-animations.h"  // cairo_dock_animation_will_be_visible
+#include "cairo-dock-X-manager.h"  // g_desktopGeometry
+#define _MANAGER_DEF_
 #include "cairo-dock-container.h"
 
-static gboolean s_bSticky = TRUE;
+// public (manager, config, data)
+CairoContainersParam myContainersParam;
+CairoContainersManager myContainersMgr;
+CairoContainer *g_pPrimaryContainer = NULL;
+CairoDockDesktopBackground *g_pFakeTransparencyDesktopBg = NULL;
 gboolean g_bUseGlitz = FALSE;
 
-CairoContainer *g_pPrimaryContainer = NULL;
+// dependancies
+extern CairoDockGLConfig g_openglConfig;
 extern gboolean g_bUseOpenGL;
 extern CairoDockHidingEffect *g_pHidingBackend;  // cairo_dock_is_hidden
-extern CairoDockDesktopGeometry g_desktopGeometry;
+extern CairoDockDesktopGeometry g_desktopGeometry;  // _place_menu_on_icon
+
+// private
+static gboolean s_bSticky = TRUE;
 
 
 static gboolean _cairo_dock_on_delete (GtkWidget *pWidget, GdkEvent *event, gpointer data)
@@ -77,12 +87,22 @@ GtkWidget *cairo_dock_init_container_full (CairoContainer *pContainer, gboolean
 		gtk_window_stick (GTK_WINDOW (pWindow));
 	gtk_window_set_skip_pager_hint (GTK_WINDOW(pWindow), TRUE);
 	gtk_window_set_skip_taskbar_hint (GTK_WINDOW(pWindow), TRUE);
+
+	// needed since gtk+-3.0 but it's possible that this resize grip has been backported to gtk+-2.0 (e.g. in Ubuntu Natty...)
+	#if (GTK_MAJOR_VERSION >= 3 || ENABLE_GTK_GRIP == 1)
+	gtk_window_set_has_resize_grip (GTK_WINDOW(pWindow), FALSE);
+	#endif
 	
 	cairo_dock_set_colormap_for_window (pWindow);
 	if (g_bUseOpenGL && bOpenGLWindow)
 	{
 		cairo_dock_set_gl_capabilities (pWindow);
+		pContainer->iAnimationDeltaT = myContainersParam.iGLAnimationDeltaT;
 	}
+	else
+		pContainer->iAnimationDeltaT = myContainersParam.iCairoAnimationDeltaT;
+	if (pContainer->iAnimationDeltaT == 0)
+		pContainer->iAnimationDeltaT = 30;
 	
 	g_signal_connect (G_OBJECT (pWindow),
 		"delete-event",
@@ -91,12 +111,14 @@ GtkWidget *cairo_dock_init_container_full (CairoContainer *pContainer, gboolean
 	
 	gtk_widget_set_app_paintable (pWindow, TRUE);
 	gtk_window_set_decorated (GTK_WINDOW (pWindow), FALSE);
+	pContainer->pWidget = pWindow;
+	
+	cairo_dock_install_notifications_on_object (pContainer, NB_NOTIFICATIONS_CONTAINER);  // l'implementation du container installera par-dessus ses notifications.
 	
 	if (g_pPrimaryContainer == NULL)
 	{
 		g_pPrimaryContainer = pContainer;
 	}
-	pContainer->pWidget = pWindow;
 	return pWindow;
 }
 
@@ -109,6 +131,8 @@ void cairo_dock_finish_container (CairoContainer *pContainer)
 		g_source_remove (pContainer->iSidGLAnimation);
 		pContainer->iSidGLAnimation = 0;
 	}
+	cairo_dock_clear_notifications_on_object (pContainer);
+	pContainer->pNotificationsTab = NULL;
 	if (g_pPrimaryContainer == pContainer)
 		g_pPrimaryContainer = NULL;
 	else if (g_bUseOpenGL && g_pPrimaryContainer != NULL)
@@ -380,7 +404,8 @@ void cairo_dock_notify_drop_data (gchar *cReceivedData, Icon *pPointedIcon, doub
 		
 		cData = sArg->str;
 		cd_debug (" notification de drop '%s'", cData);
-		cairo_dock_notify (CAIRO_DOCK_DROP_DATA, cData, pPointedIcon, fOrder, pContainer);
+		cairo_dock_notify_on_object (&myContainersMgr, NOTIFICATION_DROP_DATA, cData, pPointedIcon, fOrder, pContainer);
+		cairo_dock_notify_on_object (pContainer, NOTIFICATION_DROP_DATA, cData, pPointedIcon, fOrder, pContainer);
 	}
 	
 	g_strfreev (cStringList);
@@ -396,6 +421,10 @@ gboolean cairo_dock_emit_signal_on_container (CairoContainer *pContainer, const
 }
 gboolean cairo_dock_emit_leave_signal (CairoContainer *pContainer)
 {
+	if (pContainer->bIsHorizontal)
+		gdk_window_get_pointer (pContainer->pWidget->window, &pContainer->iMouseX, &pContainer->iMouseY, NULL);
+	else
+		gdk_window_get_pointer (pContainer->pWidget->window, &pContainer->iMouseY, &pContainer->iMouseX, NULL);
 	return cairo_dock_emit_signal_on_container (pContainer, "leave-notify-event");
 }
 gboolean cairo_dock_emit_enter_signal (CairoContainer *pContainer)
@@ -409,13 +438,10 @@ static void _cairo_dock_delete_menu (GtkMenuShell *menu, CairoDock *pDock)
 	g_return_if_fail (CAIRO_DOCK_IS_DOCK (pDock));
 	pDock->bMenuVisible = FALSE;
 	
-	cd_message ("on force a quitter");
+	//g_print ("on force a quitter\n");
 	pDock->container.bInside = TRUE;
-	///pDock->bAtBottom = FALSE;
+	// on recupere la position de la souris avant le leave, car le clic droit a genere precedemment un leave-event avec des coordonnees nulles (0;0), donc le dock a perdu la position de la souris; du coup, lors du leave qu'on s'apprete a envoyer, il ne verra pas si la souris est encore dedans, et donc se cachera/retrecira, ce qu'on ne veut pas.
 	cairo_dock_emit_leave_signal (CAIRO_CONTAINER (pDock));
-	/*cairo_dock_on_leave_notify (pDock->container.pWidget,
-		NULL,
-		pDock);*/
 }
 static void _place_menu_on_icon (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer *data)
 {
@@ -435,7 +461,7 @@ static void _place_menu_on_icon (GtkMenu *menu, gint *x, gint *y, gboolean *push
 	if (pContainer->bIsHorizontal)
 	{
 		*x = x0;
-		if (pContainer->bDirectionUp)
+		if (y0 > g_desktopGeometry.iXScreenHeight[pContainer->bIsHorizontal]/2)  // pContainer->bDirectionUp
 			*y = y0 - h;
 		else
 			*y = y0 + pIcon->fHeight * pIcon->fScale;
@@ -443,7 +469,7 @@ static void _place_menu_on_icon (GtkMenu *menu, gint *x, gint *y, gboolean *push
 	else
 	{
 		*y = MIN (x0, g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - h);
-		if (pContainer->bDirectionUp)
+		if (y0 > g_desktopGeometry.iXScreenHeight[pContainer->bIsHorizontal]/2)  // pContainer->bDirectionUp
 			*x = y0 - w;
 		else
 			*x = y0 + pIcon->fHeight * pIcon->fScale;
@@ -521,9 +547,9 @@ GtkWidget *cairo_dock_add_in_menu_with_stock_and_data (const gchar *cLabel, cons
 
 
 static GtkWidget *s_pMenu = NULL;
-static gboolean _on_delete_menu (GtkWidget *widget, GdkEvent  *event, gpointer   user_data)
+static gboolean _on_destroy_menu (GtkWidget *widget, GdkEvent  *event, gpointer   user_data)
 {
-	g_print ("*** menu deleted\n");
+	cd_debug ("*** menu destroyed");
 	s_pMenu = NULL;
 	return FALSE;
 }
@@ -531,6 +557,7 @@ GtkWidget *cairo_dock_build_menu (Icon *icon, CairoContainer *pContainer)
 {
 	if (s_pMenu != NULL)
 	{
+		cd_debug ("previous menu still alive");
 		gtk_widget_destroy (GTK_WIDGET (s_pMenu));
 		s_pMenu = NULL;
 	}
@@ -541,16 +568,117 @@ GtkWidget *cairo_dock_build_menu (Icon *icon, CairoContainer *pContainer)
 	
 	//\_________________________ On passe la main a ceux qui veulent y rajouter des choses.
 	gboolean bDiscardMenu = FALSE;
-	cairo_dock_notify (CAIRO_DOCK_BUILD_CONTAINER_MENU, icon, pContainer, menu, &bDiscardMenu);
+	cairo_dock_notify_on_object (&myContainersMgr, NOTIFICATION_BUILD_CONTAINER_MENU, icon, pContainer, menu, &bDiscardMenu);
+	cairo_dock_notify_on_object (pContainer, NOTIFICATION_BUILD_CONTAINER_MENU, icon, pContainer, menu, &bDiscardMenu);
 	if (bDiscardMenu)
 	{
 		gtk_widget_destroy (menu);
 		return NULL;
 	}
 	
-	cairo_dock_notify (CAIRO_DOCK_BUILD_ICON_MENU, icon, pContainer, menu);
-	g_signal_connect (G_OBJECT (menu), "delete-event", G_CALLBACK (_on_delete_menu), NULL);  // apparemment inutile.
+	cairo_dock_notify_on_object (&myContainersMgr, NOTIFICATION_BUILD_ICON_MENU, icon, pContainer, menu);
+	cairo_dock_notify_on_object (pContainer, NOTIFICATION_BUILD_ICON_MENU, icon, pContainer, menu);
+	g_signal_connect (G_OBJECT (menu), "destroy", G_CALLBACK (_on_destroy_menu), NULL);  // apparemment inutile.
 	
 	s_pMenu = menu;
 	return menu;
 }
+
+
+
+  //////////////////
+ /// GET CONFIG ///
+//////////////////
+
+static gboolean get_config (GKeyFile *pKeyFile, CairoContainersParam *pContainersParam)
+{
+	gboolean bFlushConfFileNeeded = FALSE;
+	pContainersParam->bUseFakeTransparency = cairo_dock_get_boolean_key_value (pKeyFile, "System", "fake transparency", &bFlushConfFileNeeded, FALSE, NULL, NULL);
+	if (g_bUseOpenGL && ! g_openglConfig.bAlphaAvailable)
+		pContainersParam->bUseFakeTransparency = TRUE;
+	
+	int iRefreshFrequency = cairo_dock_get_integer_key_value (pKeyFile, "System", "opengl anim freq", &bFlushConfFileNeeded, 33, NULL, NULL);
+	pContainersParam->iGLAnimationDeltaT = 1000. / iRefreshFrequency;
+	iRefreshFrequency = cairo_dock_get_integer_key_value (pKeyFile, "System", "cairo anim freq", &bFlushConfFileNeeded, 25, NULL, NULL);
+	pContainersParam->iCairoAnimationDeltaT = 1000. / iRefreshFrequency;
+	//g_print ("iGLAnimationDeltaT: %d\n", pContainersParam->iGLAnimationDeltaT);
+	
+	//pContainersParam->bConfigPanelTransparency = cairo_dock_get_boolean_key_value (pKeyFile, "System", "config transparency", &bFlushConfFileNeeded, TRUE, NULL, NULL);
+	return bFlushConfFileNeeded;
+}
+
+
+  ////////////
+ /// LOAD ///
+////////////
+
+static void load (void)
+{
+	if (myContainersParam.bUseFakeTransparency)
+	{
+		g_pFakeTransparencyDesktopBg = cairo_dock_get_desktop_background (g_bUseOpenGL);
+	}
+}
+
+
+  //////////////
+ /// RELOAD ///
+//////////////
+
+static void _set_below (CairoDock *pDock, gpointer data)
+{
+	gtk_window_set_keep_below (GTK_WINDOW (pDock->container.pWidget), GPOINTER_TO_INT (data));
+}
+static void reload (CairoContainersParam *pPrevContainers, CairoContainersParam *pContainers)
+{
+		//\_______________ Fake Transparency.
+	if (pContainers->bUseFakeTransparency && ! pPrevContainers->bUseFakeTransparency)
+	{
+		cairo_dock_foreach_root_docks ((GFunc)_set_below, GINT_TO_POINTER (TRUE));
+		g_pFakeTransparencyDesktopBg = cairo_dock_get_desktop_background (g_bUseOpenGL);
+	}
+	else if (! pContainers->bUseFakeTransparency && pPrevContainers->bUseFakeTransparency)
+	{
+		cairo_dock_foreach_root_docks ((GFunc)_set_below, GINT_TO_POINTER (FALSE));
+		cairo_dock_destroy_desktop_background (g_pFakeTransparencyDesktopBg);
+		g_pFakeTransparencyDesktopBg = NULL;
+	}
+}
+
+
+  //////////////
+ /// UNLOAD ///
+//////////////
+
+static void unload (void)
+{
+	g_pFakeTransparencyDesktopBg = NULL;  // no need to unref it, since everything is going to be unloaded, including the desktop_bg.
+}
+
+
+  ///////////////
+ /// MANAGER ///
+///////////////
+
+void gldi_register_containers_manager (void)
+{
+	// Manager
+	memset (&myContainersMgr, 0, sizeof (CairoContainersManager));
+	myContainersMgr.mgr.cModuleName 	= "Containers";
+	myContainersMgr.mgr.init 		= NULL;
+	myContainersMgr.mgr.load 		= load;
+	myContainersMgr.mgr.unload 		= unload;
+	myContainersMgr.mgr.reload 		= (GldiManagerReloadFunc)reload;
+	myContainersMgr.mgr.get_config 	= (GldiManagerGetConfigFunc)get_config;
+	myContainersMgr.mgr.reset_config = (GldiManagerResetConfigFunc)NULL;
+	// Config
+	myContainersMgr.mgr.pConfig = (GldiManagerConfigPtr*)&myContainersParam;
+	myContainersMgr.mgr.iSizeOfConfig = sizeof (CairoContainersParam);
+	// data
+	myContainersMgr.mgr.pData = (GldiManagerDataPtr*)NULL;
+	myContainersMgr.mgr.iSizeOfData = 0;
+	// signals
+	cairo_dock_install_notifications_on_object (&myContainersMgr, NB_NOTIFICATIONS_CONTAINER);
+	// register
+	gldi_register_manager (GLDI_MANAGER(&myContainersMgr));
+}
