@@ -36,9 +36,11 @@
 
 #include <gdk/gdkx.h>
 #include "cairo-dock-draw.h"
-#include "cairo-dock-modules.h"
+#include "cairo-dock-module-factory.h"
+#include "cairo-dock-module-manager.h"  // cairo_dock_detach_module_instance
 #include "cairo-dock-dialog-manager.h"
-#include "cairo-dock-icons.h"
+#include "cairo-dock-icon-factory.h"
+#include "cairo-dock-icon-facility.h"
 #include "cairo-dock-config.h"
 #include "cairo-dock-X-manager.h"
 #include "cairo-dock-notifications.h"
@@ -48,11 +50,11 @@
 #include "cairo-dock-surface-factory.h"
 #include "cairo-dock-backends-manager.h"
 #include "cairo-dock-draw-opengl.h"
-#include "cairo-dock-load.h"
+#include "cairo-dock-image-buffer.h"
 #include "cairo-dock-animations.h"
-#include "cairo-dock-internal-desklets.h"
 #include "cairo-dock-gui-manager.h"
 #include "cairo-dock-launcher-manager.h"
+#include "cairo-dock-desklet-manager.h"
 #include "cairo-dock-desklet-factory.h"
 
 extern gboolean g_bUseOpenGL;
@@ -61,6 +63,8 @@ extern CairoDockDesktopGeometry g_desktopGeometry;
 static void _cairo_dock_reserve_space_for_desklet (CairoDesklet *pDesklet, gboolean bReserve);
 static void on_drag_data_received_desklet (GtkWidget *pWidget, GdkDragContext *dc, gint x, gint y, GtkSelectionData *selection_data, guint info, guint t, CairoDesklet *pDesklet);
 
+#define CD_WRITE_DELAY 600  // ms
+
   ///////////////
  /// SIGNALS ///
 ///////////////
@@ -69,12 +73,26 @@ static gboolean on_expose_desklet(GtkWidget *pWidget,
 	GdkEventExpose *pExpose,
 	CairoDesklet *pDesklet)
 {
-	if (pDesklet->iDesiredWidth != 0 && pDesklet->iDesiredHeight != 0 && (pDesklet->iKnownWidth != pDesklet->iDesiredWidth || pDesklet->iKnownHeight != pDesklet->iDesiredHeight))
+	if (pDesklet->iDesiredWidth != 0 && pDesklet->iDesiredHeight != 0 && (pDesklet->iKnownWidth != pDesklet->iDesiredWidth || pDesklet->iKnownHeight != pDesklet->iDesiredHeight))  // skip the drawing until the desklet has reached its size.
 	{
 		//g_print ("on saute le dessin\n");
 		if (g_bUseOpenGL)
 		{
-			// dessiner la fausse transparence.
+			GdkGLContext *pGlContext = gtk_widget_get_gl_context (pDesklet->container.pWidget);
+			GdkGLDrawable *pGlDrawable = gtk_widget_get_gl_drawable (pDesklet->container.pWidget);
+			if (!gdk_gl_drawable_gl_begin (pGlDrawable, pGlContext))
+				return FALSE;
+			
+			glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+			glLoadIdentity ();
+			
+			cairo_dock_apply_desktop_background_opengl (CAIRO_CONTAINER (pDesklet));
+			
+			if (gdk_gl_drawable_is_double_buffered (pGlDrawable))
+				gdk_gl_drawable_swap_buffers (pGlDrawable);
+			else
+				glFlush ();
+			gdk_gl_drawable_gl_end (pGlDrawable);
 		}
 		else
 		{
@@ -96,7 +114,8 @@ static gboolean on_expose_desklet(GtkWidget *pWidget,
 		
 		cairo_dock_apply_desktop_background_opengl (CAIRO_CONTAINER (pDesklet));
 		
-		cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_RENDER_DESKLET, pDesklet, NULL);
+		cairo_dock_notify_on_object (&myDeskletsMgr, NOTIFICATION_RENDER_DESKLET, pDesklet, NULL);
+		cairo_dock_notify_on_object (pDesklet, NOTIFICATION_RENDER_DESKLET, pDesklet, NULL);
 		
 		if (gdk_gl_drawable_is_double_buffered (pGlDrawable))
 			gdk_gl_drawable_swap_buffers (pGlDrawable);
@@ -108,7 +127,8 @@ static gboolean on_expose_desklet(GtkWidget *pWidget,
 	{
 		cairo_t *pCairoContext = cairo_dock_create_drawing_context_on_container (CAIRO_CONTAINER (pDesklet));
 		
-		cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_RENDER_DESKLET, pDesklet, pCairoContext);
+		cairo_dock_notify_on_object (&myDeskletsMgr, NOTIFICATION_RENDER_DESKLET, pDesklet, pCairoContext);
+		cairo_dock_notify_on_object (pDesklet, NOTIFICATION_RENDER_DESKLET, pDesklet, pCairoContext);
 		
 		cairo_destroy (pCairoContext);
 	}
@@ -135,10 +155,10 @@ static void _cairo_dock_set_desklet_input_shape (CairoDesklet *pDesklet)
 		cairo_paint (pCairoContext);
 		cairo_set_source_rgba (pCairoContext, 1., 1., 1., 1.);
 		cairo_rectangle (pCairoContext,
-			pDesklet->container.iWidth - myDesklets.iDeskletButtonSize,
-			pDesklet->container.iHeight - myDesklets.iDeskletButtonSize,
-			myDesklets.iDeskletButtonSize,
-			myDesklets.iDeskletButtonSize);
+			pDesklet->container.iWidth - myDeskletsParam.iDeskletButtonSize,
+			pDesklet->container.iHeight - myDeskletsParam.iDeskletButtonSize,
+			myDeskletsParam.iDeskletButtonSize,
+			myDeskletsParam.iDeskletButtonSize);
 		cairo_fill (pCairoContext);
 		cairo_destroy (pCairoContext);
 		gtk_widget_input_shape_combine_mask (pDesklet->container.pWidget,
@@ -152,16 +172,14 @@ static void _cairo_dock_set_desklet_input_shape (CairoDesklet *pDesklet)
 
 static gboolean _cairo_dock_write_desklet_size (CairoDesklet *pDesklet)
 {
-	if ((pDesklet->iDesiredWidth == 0 && pDesklet->iDesiredHeight == 0) && pDesklet->pIcon != NULL && pDesklet->pIcon->pModuleInstance != NULL)
+	if ((pDesklet->iDesiredWidth == 0 && pDesklet->iDesiredHeight == 0) && pDesklet->pIcon != NULL && pDesklet->pIcon->pModuleInstance != NULL && cairo_dock_desklet_manager_is_ready ())
 	{
 		gchar *cSize = g_strdup_printf ("%d;%d", pDesklet->container.iWidth, pDesklet->container.iHeight);
 		cairo_dock_update_conf_file (pDesklet->pIcon->pModuleInstance->cConfFilePath,
 			G_TYPE_STRING, "Desklet", "size", cSize,
 			G_TYPE_INVALID);
 		g_free (cSize);
-		cairo_dock_update_desklet_size_in_gui (pDesklet->pIcon->pModuleInstance,
-			pDesklet->container.iWidth,
-			pDesklet->container.iHeight);
+		cairo_dock_notify_on_object (&myDeskletsMgr, NOTIFICATION_CONFIGURE_DESKLET, pDesklet);
 	}
 	pDesklet->iSidWriteSize = 0;
 	pDesklet->iKnownWidth = pDesklet->container.iWidth;
@@ -271,9 +289,7 @@ static gboolean _cairo_dock_write_desklet_position (CairoDesklet *pDesklet)
 			G_TYPE_INT, "Desklet", "y position", iRelativePositionY,
 			G_TYPE_INT, "Desklet", "num desktop", iNumDesktop,
 			G_TYPE_INVALID);
-		cairo_dock_update_desklet_position_in_gui (pDesklet->pIcon->pModuleInstance,
-			iRelativePositionX,
-			iRelativePositionY);
+		cairo_dock_notify_on_object (&myDeskletsMgr, NOTIFICATION_CONFIGURE_DESKLET, pDesklet);
 	}
 	
 	if (pDesklet->bSpaceReserved)  // l'espace est reserve, on reserve a la nouvelle position.
@@ -327,7 +343,7 @@ static gboolean on_configure_desklet (GtkWidget* pWidget,
 		{
 			g_source_remove (pDesklet->iSidWriteSize);
 		}
-		pDesklet->iSidWriteSize = g_timeout_add (500, (GSourceFunc) _cairo_dock_write_desklet_size, (gpointer) pDesklet);
+		pDesklet->iSidWriteSize = g_timeout_add (CD_WRITE_DELAY, (GSourceFunc) _cairo_dock_write_desklet_size, (gpointer) pDesklet);
 	}
 	
 	int x = pEvent->x, y = pEvent->y;
@@ -346,11 +362,14 @@ static gboolean on_configure_desklet (GtkWidget* pWidget,
 		pDesklet->container.iWindowPositionX = x;
 		pDesklet->container.iWindowPositionY = y;
 
-		if (pDesklet->iSidWritePosition != 0)
+		if (cairo_dock_desklet_manager_is_ready ())
 		{
-			g_source_remove (pDesklet->iSidWritePosition);
+			if (pDesklet->iSidWritePosition != 0)
+			{
+				g_source_remove (pDesklet->iSidWritePosition);
+			}
+			pDesklet->iSidWritePosition = g_timeout_add (CD_WRITE_DELAY, (GSourceFunc) _cairo_dock_write_desklet_position, (gpointer) pDesklet);
 		}
-		pDesklet->iSidWritePosition = g_timeout_add (500, (GSourceFunc) _cairo_dock_write_desklet_position, (gpointer) pDesklet);
 	}
 	pDesklet->moving = FALSE;
 
@@ -364,11 +383,9 @@ static gboolean on_scroll_desklet (GtkWidget* pWidget,
 	//g_print ("scroll\n");
 	if (! (pScroll->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK)))
 	{
-		Icon *icon = cairo_dock_find_clicked_icon_in_desklet (pDesklet);
-		///if (icon != NULL)
-		{
-			cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_SCROLL_ICON, icon, pDesklet, pScroll->direction);
-		}
+		Icon *icon = cairo_dock_find_clicked_icon_in_desklet (pDesklet);  // can be NULL
+		cairo_dock_notify_on_object (&myContainersMgr, NOTIFICATION_SCROLL_ICON, icon, pDesklet, pScroll->direction);
+		cairo_dock_notify_on_object (CAIRO_CONTAINER (pDesklet), NOTIFICATION_SCROLL_ICON, icon, pDesklet, pScroll->direction);
 	}
 	return FALSE;
 }
@@ -379,7 +396,8 @@ static gboolean on_unmap_desklet (GtkWidget* pWidget,
 {
 	cd_debug ("unmap desklet (bAllowMinimize:%d)\n", pDesklet->bAllowMinimize);
 	Window Xid = GDK_WINDOW_XID (pWidget->window);
-	if (cairo_dock_window_is_utility (Xid))  // sur la couche des widgets, on ne fait rien.
+	if (pDesklet->iVisibility == CAIRO_DESKLET_ON_WIDGET_LAYER)  // on the widget layer, let pass the unmap event..
+	//if (cairo_dock_window_is_utility (Xid))  // sur la couche des widgets, on ne fait rien.
 		return FALSE;
 	if (! pDesklet->bAllowMinimize)
 	{
@@ -418,18 +436,18 @@ static gboolean on_button_press_desklet(GtkWidget *pWidget,
 			{
 				///pDesklet->container.iMouseX = pButton->x;  // pour le deplacement manuel.
 				///pDesklet->container.iMouseY = pButton->y;
-				if (pButton->x < myDesklets.iDeskletButtonSize && pButton->y < myDesklets.iDeskletButtonSize)
+				if (pButton->x < myDeskletsParam.iDeskletButtonSize && pButton->y < myDeskletsParam.iDeskletButtonSize)
 					pDesklet->rotating = TRUE;
-				else if (pButton->x > pDesklet->container.iWidth - myDesklets.iDeskletButtonSize && pButton->y < myDesklets.iDeskletButtonSize)
+				else if (pButton->x > pDesklet->container.iWidth - myDeskletsParam.iDeskletButtonSize && pButton->y < myDeskletsParam.iDeskletButtonSize)
 					pDesklet->retaching = TRUE;
-				else if (pButton->x > (pDesklet->container.iWidth - myDesklets.iDeskletButtonSize)/2 && pButton->x < (pDesklet->container.iWidth + myDesklets.iDeskletButtonSize)/2 && pButton->y < myDesklets.iDeskletButtonSize)
+				else if (pButton->x > (pDesklet->container.iWidth - myDeskletsParam.iDeskletButtonSize)/2 && pButton->x < (pDesklet->container.iWidth + myDeskletsParam.iDeskletButtonSize)/2 && pButton->y < myDeskletsParam.iDeskletButtonSize)
 					pDesklet->rotatingY = TRUE;
-				else if (pButton->y > (pDesklet->container.iHeight - myDesklets.iDeskletButtonSize)/2 && pButton->y < (pDesklet->container.iHeight + myDesklets.iDeskletButtonSize)/2 && pButton->x < myDesklets.iDeskletButtonSize)
+				else if (pButton->y > (pDesklet->container.iHeight - myDeskletsParam.iDeskletButtonSize)/2 && pButton->y < (pDesklet->container.iHeight + myDeskletsParam.iDeskletButtonSize)/2 && pButton->x < myDeskletsParam.iDeskletButtonSize)
 					pDesklet->rotatingX = TRUE;
 				else
 					pDesklet->time = pButton->time;
 			}
-			if (pDesklet->bAllowNoClickable && pButton->x > pDesklet->container.iWidth - myDesklets.iDeskletButtonSize && pButton->y > pDesklet->container.iHeight - myDesklets.iDeskletButtonSize)
+			if (pDesklet->bAllowNoClickable && pButton->x > pDesklet->container.iWidth - myDeskletsParam.iDeskletButtonSize && pButton->y > pDesklet->container.iHeight - myDeskletsParam.iDeskletButtonSize)
 				pDesklet->making_transparent = TRUE;
 		}
 		else if (pButton->type == GDK_BUTTON_RELEASE)
@@ -453,11 +471,12 @@ static gboolean on_button_press_desklet(GtkWidget *pWidget,
 					G_TYPE_INT, "Desklet", "rotation", (int) (pDesklet->fRotation / G_PI * 180.),
 					G_TYPE_INVALID);
 				gtk_widget_queue_draw (pDesklet->container.pWidget);
+				cairo_dock_notify_on_object (&myDeskletsMgr, NOTIFICATION_CONFIGURE_DESKLET, pDesklet);
 			}
 			else if (pDesklet->retaching)
 			{
 				pDesklet->retaching = FALSE;
-				if (x > pDesklet->container.iWidth - myDesklets.iDeskletButtonSize && y < myDesklets.iDeskletButtonSize)  // on verifie qu'on est encore dedans.
+				if (x > pDesklet->container.iWidth - myDeskletsParam.iDeskletButtonSize && y < myDeskletsParam.iDeskletButtonSize)  // on verifie qu'on est encore dedans.
 				{
 					Icon *icon = pDesklet->pIcon;
 					g_return_val_if_fail (CAIRO_DOCK_IS_APPLET (icon), FALSE);
@@ -469,7 +488,7 @@ static gboolean on_button_press_desklet(GtkWidget *pWidget,
 			{
 				cd_debug ("pDesklet->making_transparent\n");
 				pDesklet->making_transparent = FALSE;
-				if (x > pDesklet->container.iWidth - myDesklets.iDeskletButtonSize && y > pDesklet->container.iHeight - myDesklets.iDeskletButtonSize)  // on verifie qu'on est encore dedans.
+				if (x > pDesklet->container.iWidth - myDeskletsParam.iDeskletButtonSize && y > pDesklet->container.iHeight - myDeskletsParam.iDeskletButtonSize)  // on verifie qu'on est encore dedans.
 				{
 					Icon *icon = pDesklet->pIcon;
 					g_return_val_if_fail (CAIRO_DOCK_IS_APPLET (icon), FALSE);
@@ -505,7 +524,8 @@ static gboolean on_button_press_desklet(GtkWidget *pWidget,
 			else
 			{
 				Icon *pClickedIcon = cairo_dock_find_clicked_icon_in_desklet (pDesklet);
-				cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_CLICK_ICON, pClickedIcon, pDesklet, pButton->state);
+				cairo_dock_notify_on_object (&myContainersMgr, NOTIFICATION_CLICK_ICON, pClickedIcon, pDesklet, pButton->state);
+				cairo_dock_notify_on_object (CAIRO_CONTAINER (pDesklet), NOTIFICATION_CLICK_ICON, pClickedIcon, pDesklet, pButton->state);
 			}
 			// prudence.
 			pDesklet->rotating = FALSE;
@@ -516,10 +536,11 @@ static gboolean on_button_press_desklet(GtkWidget *pWidget,
 		}
 		else if (pButton->type == GDK_2BUTTON_PRESS)
 		{
-			if (! (pButton->x < myDesklets.iDeskletButtonSize && pButton->y < myDesklets.iDeskletButtonSize) && ! (pButton->x > (pDesklet->container.iWidth - myDesklets.iDeskletButtonSize)/2 && pButton->x < (pDesklet->container.iWidth + myDesklets.iDeskletButtonSize)/2 && pButton->y < myDesklets.iDeskletButtonSize))
+			if (! (pButton->x < myDeskletsParam.iDeskletButtonSize && pButton->y < myDeskletsParam.iDeskletButtonSize) && ! (pButton->x > (pDesklet->container.iWidth - myDeskletsParam.iDeskletButtonSize)/2 && pButton->x < (pDesklet->container.iWidth + myDeskletsParam.iDeskletButtonSize)/2 && pButton->y < myDeskletsParam.iDeskletButtonSize))
 			{
-				Icon *pClickedIcon = cairo_dock_find_clicked_icon_in_desklet (pDesklet);
-				cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_DOUBLE_CLICK_ICON, pClickedIcon, pDesklet);
+				Icon *pClickedIcon = cairo_dock_find_clicked_icon_in_desklet (pDesklet);  // can be NULL
+				cairo_dock_notify_on_object (&myContainersMgr, NOTIFICATION_DOUBLE_CLICK_ICON, pClickedIcon, pDesklet);
+				cairo_dock_notify_on_object (CAIRO_CONTAINER (pDesklet), NOTIFICATION_DOUBLE_CLICK_ICON, pClickedIcon, pDesklet);
 			}
 		}
 	}
@@ -533,15 +554,16 @@ static gboolean on_button_press_desklet(GtkWidget *pWidget,
 	}
 	else if (pButton->button == 2 && pButton->type == GDK_BUTTON_PRESS)  // clique milieu.
 	{
-		if (pButton->x < myDesklets.iDeskletButtonSize && pButton->y < myDesklets.iDeskletButtonSize)
+		if (pButton->x < myDeskletsParam.iDeskletButtonSize && pButton->y < myDeskletsParam.iDeskletButtonSize)
 		{
 			pDesklet->fRotation = 0.;
 			gtk_widget_queue_draw (pDesklet->container.pWidget);
 			cairo_dock_update_conf_file (pDesklet->pIcon->pModuleInstance->cConfFilePath,
 				G_TYPE_INT, "Desklet", "rotation", 0,
 				G_TYPE_INVALID);
+			cairo_dock_notify_on_object (&myDeskletsMgr, NOTIFICATION_CONFIGURE_DESKLET, pDesklet);
 		}
-		else if (pButton->x > (pDesklet->container.iWidth - myDesklets.iDeskletButtonSize)/2 && pButton->x < (pDesklet->container.iWidth + myDesklets.iDeskletButtonSize)/2 && pButton->y < myDesklets.iDeskletButtonSize)
+		else if (pButton->x > (pDesklet->container.iWidth - myDeskletsParam.iDeskletButtonSize)/2 && pButton->x < (pDesklet->container.iWidth + myDeskletsParam.iDeskletButtonSize)/2 && pButton->y < myDeskletsParam.iDeskletButtonSize)
 		{
 			pDesklet->fDepthRotationY = 0.;
 			gtk_widget_queue_draw (pDesklet->container.pWidget);
@@ -549,7 +571,7 @@ static gboolean on_button_press_desklet(GtkWidget *pWidget,
 				G_TYPE_INT, "Desklet", "depth rotation y", 0,
 				G_TYPE_INVALID);
 		}
-		else if (pButton->y > (pDesklet->container.iHeight - myDesklets.iDeskletButtonSize)/2 && pButton->y < (pDesklet->container.iHeight + myDesklets.iDeskletButtonSize)/2 && pButton->x < myDesklets.iDeskletButtonSize)
+		else if (pButton->y > (pDesklet->container.iHeight - myDeskletsParam.iDeskletButtonSize)/2 && pButton->y < (pDesklet->container.iHeight + myDeskletsParam.iDeskletButtonSize)/2 && pButton->x < myDeskletsParam.iDeskletButtonSize)
 		{
 			pDesklet->fDepthRotationX = 0.;
 			gtk_widget_queue_draw (pDesklet->container.pWidget);
@@ -559,7 +581,8 @@ static gboolean on_button_press_desklet(GtkWidget *pWidget,
 		}
 		else
 		{
-			cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_MIDDLE_CLICK_ICON, pDesklet->pIcon, pDesklet);
+			cairo_dock_notify_on_object (&myContainersMgr, NOTIFICATION_MIDDLE_CLICK_ICON, pDesklet->pIcon, pDesklet);
+			cairo_dock_notify_on_object (CAIRO_CONTAINER (pDesklet), NOTIFICATION_MIDDLE_CLICK_ICON, pDesklet->pIcon, pDesklet);
 		}
 	}
 	return FALSE;
@@ -584,7 +607,7 @@ static void on_drag_data_received_desklet (GtkWidget *pWidget, GdkDragContext *d
 	cairo_dock_notify_drop_data (cReceivedData, pClickedIcon, 0, CAIRO_CONTAINER (pDesklet));
 }
 
-static gboolean on_motion_notify_desklet(GtkWidget *pWidget,
+static gboolean on_motion_notify_desklet (GtkWidget *pWidget,
 	GdkEventMotion* pMotion,
 	CairoDesklet *pDesklet)
 {
@@ -597,7 +620,8 @@ static gboolean on_motion_notify_desklet(GtkWidget *pWidget,
 		pDesklet->container.iMouseX = pMotion->x;
 		pDesklet->container.iMouseY = pMotion->y;
 		gboolean bStartAnimation = FALSE;
-		cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_MOUSE_MOVED, pDesklet, &bStartAnimation);
+		cairo_dock_notify_on_object (&myContainersMgr, NOTIFICATION_MOUSE_MOVED, pDesklet, &bStartAnimation);
+		cairo_dock_notify_on_object (CAIRO_CONTAINER (pDesklet), NOTIFICATION_MOUSE_MOVED, pDesklet, &bStartAnimation);
 		if (bStartAnimation)
 			cairo_dock_launch_animation (CAIRO_CONTAINER (pDesklet));
 	}
@@ -645,7 +669,8 @@ static gboolean on_motion_notify_desklet(GtkWidget *pWidget,
 				pIcon->bPointed = TRUE;
 				
 				//g_print ("on survole %s\n", pIcon->cName);
-				cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_ENTER_ICON, pIcon, pDesklet, &bStartAnimation);
+				cairo_dock_notify_on_object (&myContainersMgr, NOTIFICATION_ENTER_ICON, pIcon, pDesklet, &bStartAnimation);
+				cairo_dock_notify_on_object (CAIRO_CONTAINER (pDesklet), NOTIFICATION_ENTER_ICON, pIcon, pDesklet, &bStartAnimation);
 			}
 		}
 		else
@@ -656,7 +681,8 @@ static gboolean on_motion_notify_desklet(GtkWidget *pWidget,
 				pPointedIcon->bPointed = FALSE;
 				
 				//g_print ("kedal\n");
-				cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_ENTER_ICON, pPointedIcon, pDesklet, &bStartAnimation);
+				cairo_dock_notify_on_object (&myContainersMgr, NOTIFICATION_ENTER_ICON, pPointedIcon, pDesklet, &bStartAnimation);
+				cairo_dock_notify_on_object (CAIRO_CONTAINER (pDesklet), NOTIFICATION_ENTER_ICON, pPointedIcon, pDesklet, &bStartAnimation);
 			}
 		}
 		if (bStartAnimation)
@@ -691,7 +717,8 @@ static gboolean on_enter_desklet (GtkWidget* pWidget,
 		///if (g_bUseOpenGL)
 		{
 			gboolean bStartAnimation = FALSE;
-			cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_ENTER_DESKLET, pDesklet, &bStartAnimation);
+			cairo_dock_notify_on_object (&myDeskletsMgr, NOTIFICATION_ENTER_DESKLET, pDesklet, &bStartAnimation);
+			cairo_dock_notify_on_object (pDesklet, NOTIFICATION_ENTER_DESKLET, pDesklet, &bStartAnimation);
 			if (bStartAnimation)
 				cairo_dock_launch_animation (CAIRO_CONTAINER (pDesklet));
 		}
@@ -714,7 +741,8 @@ static gboolean on_leave_desklet (GtkWidget* pWidget,
 	gtk_widget_queue_draw (pWidget);  // redessin des boutons.
 	
 	gboolean bStartAnimation = FALSE;
-	cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_LEAVE_DESKLET, pDesklet, &bStartAnimation);
+	cairo_dock_notify_on_object (&myDeskletsMgr, NOTIFICATION_LEAVE_DESKLET, pDesklet, &bStartAnimation);
+	cairo_dock_notify_on_object (pDesklet, NOTIFICATION_LEAVE_DESKLET, pDesklet, &bStartAnimation);
 	if (bStartAnimation)
 		cairo_dock_launch_animation (CAIRO_CONTAINER (pDesklet));
 	
@@ -746,6 +774,7 @@ CairoDesklet *cairo_dock_new_desklet (void)
 	pDesklet->container.iface.set_icon_size = _cairo_dock_set_icon_size;
 	
 	GtkWidget* pWindow = cairo_dock_init_container (CAIRO_CONTAINER (pDesklet));
+	cairo_dock_install_notifications_on_object (pDesklet, NB_NOTIFICATIONS_DESKLET);
 	
 	gtk_window_set_title (GTK_WINDOW(pWindow), "cairo-dock-desklet");
 	gtk_widget_add_events( pWindow, GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK | GDK_FOCUS_CHANGE_MASK);
@@ -798,7 +827,7 @@ CairoDesklet *cairo_dock_new_desklet (void)
 		pDesklet);
 	cairo_dock_allow_widget_to_receive_data (pWindow, G_CALLBACK (on_drag_data_received_desklet), pDesklet);
 	
-	gtk_widget_show_all(pWindow);
+	gtk_widget_show_all (pWindow);
 	
 	return pDesklet;
 }
@@ -812,7 +841,8 @@ void cairo_dock_free_desklet (CairoDesklet *pDesklet)
 		g_source_remove (pDesklet->iSidWriteSize);
 	if (pDesklet->iSidWritePosition != 0)
 		g_source_remove (pDesklet->iSidWritePosition);
-	cairo_dock_notify_on_container (CAIRO_CONTAINER (pDesklet), CAIRO_DOCK_STOP_DESKLET, pDesklet);
+	cairo_dock_notify_on_object (&myDeskletsMgr, NOTIFICATION_STOP_DESKLET, pDesklet);
+	cairo_dock_notify_on_object (pDesklet, NOTIFICATION_STOP_DESKLET, pDesklet);
 	
 	cairo_dock_steal_interactive_widget_from_desklet (pDesklet);
 
@@ -934,7 +964,7 @@ void cairo_dock_load_desklet_decorations (CairoDesklet *pDesklet)
 	if (pDesklet->cDecorationTheme == NULL || strcmp (pDesklet->cDecorationTheme, "personnal") == 0)
 		pDeskletDecorations = pDesklet->pUserDecoration;
 	else if (strcmp (pDesklet->cDecorationTheme, "default") == 0)
-		pDeskletDecorations = cairo_dock_get_desklet_decoration (myDesklets.cDeskletDecorationsName);
+		pDeskletDecorations = cairo_dock_get_desklet_decoration (myDeskletsParam.cDeskletDecorationsName);
 	else
 		pDeskletDecorations = cairo_dock_get_desklet_decoration (pDesklet->cDecorationTheme);
 	if (pDeskletDecorations == NULL)  // peut arriver si rendering n'a pas encore charge ses decorations.
@@ -1133,17 +1163,15 @@ static void _cairo_dock_reserve_space_for_desklet (CairoDesklet *pDesklet, gbool
 //set behaviour in compiz to: (class=Cairo-dock & type=utility)
 void cairo_dock_set_desklet_accessibility (CairoDesklet *pDesklet, CairoDeskletVisibility iVisibility, gboolean bSaveState)
 {
-	//g_print ("%s (%d)\n", __func__, iVisibility);
+	cd_debug ("%s (%d)", __func__, iVisibility);
 	
 	//\_________________ On applique la nouvelle accessibilite.
 	gtk_window_set_keep_below (GTK_WINDOW (pDesklet->container.pWidget), iVisibility == CAIRO_DESKLET_KEEP_BELOW);
+	
 	gtk_window_set_keep_above (GTK_WINDOW (pDesklet->container.pWidget), iVisibility == CAIRO_DESKLET_KEEP_ABOVE);
 
 	Window Xid = GDK_WINDOW_XID (pDesklet->container.pWidget->window);
-	if (iVisibility == CAIRO_DESKLET_ON_WIDGET_LAYER)
-		cairo_dock_set_xwindow_type_hint (Xid, "_NET_WM_WINDOW_TYPE_UTILITY");  // le hide-show le fait deconner completement, il perd son skip_task_bar ! au moins sous KDE3.
-	else
-		cairo_dock_set_xwindow_type_hint (Xid, "_NET_WM_WINDOW_TYPE_NORMAL");
+	cairo_dock_wm_set_on_widget_layer (Xid, iVisibility == CAIRO_DESKLET_ON_WIDGET_LAYER);
 	
 	if (iVisibility == CAIRO_DESKLET_RESERVE_SPACE)
 	{
@@ -1156,68 +1184,13 @@ void cairo_dock_set_desklet_accessibility (CairoDesklet *pDesklet, CairoDeskletV
 	}
 	
 	//\_________________ On enregistre le nouvel etat.
+	pDesklet->iVisibility = iVisibility;
+	
 	Icon *icon = pDesklet->pIcon;
 	if (bSaveState && CAIRO_DOCK_IS_APPLET (icon))
 		cairo_dock_update_conf_file (icon->pModuleInstance->cConfFilePath,
 			G_TYPE_INT, "Desklet", "accessibility", iVisibility,
 			G_TYPE_INVALID);
-	
-	//\_________________ On verifie que la regle de Compiz est correcte.
-	if (iVisibility == CAIRO_DESKLET_ON_WIDGET_LAYER && bSaveState)
-	{
-		// pour activer le plug-in, recuperer la liste, y rajouter widget-layer, puis envoyer :
-		//dbus-send --print-reply --type=method_call  --dest=org.freedesktop.compiz  /org/freedesktop/compiz/core/allscreens/active_plugins  org.freedesktop.compiz.get
-		// dbus-send --print-reply --type=method_call  --dest=org.freedesktop.compiz  /org/freedesktop/compiz/core/allscreens/active_plugins  org.freedesktop.compiz.set array:string:"foo",string:"fum"
-		
-		// on recupere la regle
-		gchar *cDbusAnswer = cairo_dock_launch_command_sync ("dbus-send --print-reply --type=method_call --dest=org.freedesktop.compiz /org/freedesktop/compiz/widget/screen0/match org.freedesktop.compiz.get");
-		cd_debug ("cDbusAnswer : '%s'", cDbusAnswer);
-		gchar *cRule = NULL;
-		gchar *str = (cDbusAnswer ? strchr (cDbusAnswer, '\n') : NULL);
-		if (str)
-		{
-			str ++;
-			while (*str == ' ')
-				str ++;
-			if (strncmp (str, "string", 6) == 0)
-			{
-				str += 6;
-				while (*str == ' ')
-					str ++;
-				if (*str == '"')
-				{
-					str ++;
-					gchar *ptr = strrchr (str, '"');
-					if (ptr)
-					{
-						*ptr = '\0';
-						cRule = g_strdup (str);
-					}
-				}
-			}
-		}
-		g_free (cDbusAnswer);
-		cd_debug ("got rule : '%s'", cRule);
-		
-		if (cRule == NULL)  /// on ne sait pas le distinguer d'une regle vide...
-		{
-			cd_warning ("couldn't get Widget Layer rule from Compiz");
-		}
-		
-		// on complete la regle si necessaire.
-		if (cRule == NULL || *cRule == '\0' || (g_strstr_len (cRule, -1, "class=Cairo-dock & type=utility") == NULL && g_strstr_len (cRule, -1, "(class=Cairo-dock) & (type=utility)") == NULL && g_strstr_len (cRule, -1, "name=cairo-dock & type=utility") == NULL))
-		{
-			gchar *cNewRule = (cRule == NULL || *cRule == '\0' ?
-				g_strdup ("(class=Cairo-dock & type=utility)") :
-				g_strdup_printf ("(%s) | (class=Cairo-dock & type=utility)", cRule));
-			cd_debug ("set rule : %s", cNewRule);
-			gchar *cCommand = g_strdup_printf ("dbus-send --print-reply --type=method_call --dest=org.freedesktop.compiz /org/freedesktop/compiz/widget/screen0/match org.freedesktop.compiz.set string:\"%s\"", cNewRule);
-			cairo_dock_launch_command_sync (cCommand);
-			g_free (cCommand);
-			g_free (cNewRule);
-		}
-		g_free (cRule);
-	}
 }
 
 void cairo_dock_set_desklet_sticky (CairoDesklet *pDesklet, gboolean bSticky)
@@ -1321,10 +1294,3 @@ gboolean cairo_dock_detach_icon_from_desklet (Icon *icon, CairoDesklet *pDesklet
 	// calculate icons
 	cairo_dock_update_desklet_icons (pDesklet);
 }
-
-
-gboolean cairo_dock_click_notification (gpointer pUserData, Icon *pClickedIcon, CairoDesklet *pDesklet, guint iButtonState)
-{
-	
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-}
