@@ -28,9 +28,10 @@
 #include <GL/glx.h>
 #include <gdk/x11/gdkglx.h>
 
-#include "cairo-dock-icons.h"
+#include "cairo-dock-icon-factory.h"
+#include "cairo-dock-icon-facility.h"
 #include "cairo-dock-container.h"
-#include "cairo-dock-load.h"
+#include "cairo-dock-image-buffer.h"
 #include "cairo-dock-draw.h"
 #include "cairo-dock-draw-opengl.h"
 #include "cairo-dock-log.h"
@@ -39,9 +40,6 @@
 #include "cairo-dock-dock-facility.h"
 #include "cairo-dock-backends-manager.h"
 #include "cairo-dock-surface-factory.h"
-#include "cairo-dock-internal-accessibility.h"
-#include "cairo-dock-internal-dialogs.h"
-#include "cairo-dock-internal-system.h"
 #include "cairo-dock-animations.h"
 #include "cairo-dock-notifications.h"
 #include "cairo-dock-callbacks.h"
@@ -50,6 +48,7 @@
 #include "cairo-dock-applications-manager.h"
 #include "cairo-dock-X-manager.h"
 #include "cairo-dock-X-utilities.h"
+#include "cairo-dock-dialog-manager.h"
 #include "cairo-dock-dialog-factory.h"
 
 extern CairoDockDesktopGeometry g_desktopGeometry;
@@ -65,8 +64,8 @@ static void _cairo_dock_compute_dialog_sizes (CairoDialog *pDialog)
 	
 	if (pDialog->pButtons != NULL)
 	{
-		pDialog->iButtonsWidth = pDialog->iNbButtons * myDialogs.iDialogButtonWidth + (pDialog->iNbButtons - 1) * CAIRO_DIALOG_BUTTON_GAP + 2 * CAIRO_DIALOG_TEXT_MARGIN;  // marge + bouton1 + ecart + bouton2 + marge.
-		pDialog->iButtonsHeight = CAIRO_DIALOG_VGAP + myDialogs.iDialogButtonHeight;  // il y'a toujours quelque chose au-dessus (texte et/out widget)
+		pDialog->iButtonsWidth = pDialog->iNbButtons * myDialogsParam.iDialogButtonWidth + (pDialog->iNbButtons - 1) * CAIRO_DIALOG_BUTTON_GAP + 2 * CAIRO_DIALOG_TEXT_MARGIN;  // marge + bouton1 + ecart + bouton2 + marge.
+		pDialog->iButtonsHeight = CAIRO_DIALOG_VGAP + myDialogsParam.iDialogButtonHeight;  // il y'a toujours quelque chose au-dessus (texte et/out widget)
 	}
 	
 	pDialog->iBubbleWidth = MAX (pDialog->iInteractiveWidth, MAX (pDialog->iButtonsWidth, MAX (pDialog->iMessageWidth, pDialog->iMinFrameWidth)));
@@ -74,10 +73,13 @@ static void _cairo_dock_compute_dialog_sizes (CairoDialog *pDialog)
 	if (pDialog->iBubbleWidth == 0)  // precaution.
 		pDialog->iBubbleWidth = 20;
 	if (pDialog->iBubbleHeight == 0)
-		pDialog->iBubbleHeight = 20;
+		pDialog->iBubbleHeight = 10;
 	
-	pDialog->container.iWidth = pDialog->iBubbleWidth + pDialog->iLeftMargin + pDialog->iRightMargin;
-	pDialog->container.iHeight = pDialog->iBubbleHeight + pDialog->iTopMargin + pDialog->iBottomMargin + pDialog->iMinBottomGap;  // resultat temporaire, sans la pointe.
+	pDialog->iComputedWidth = pDialog->iLeftMargin + pDialog->iBubbleWidth + pDialog->iRightMargin;
+	pDialog->iComputedHeight = pDialog->iTopMargin + pDialog->iBubbleHeight + pDialog->iBottomMargin + pDialog->iMinBottomGap;  // all included.
+	
+	pDialog->container.iWidth = pDialog->iComputedWidth;
+	pDialog->container.iHeight = pDialog->iComputedHeight;
 }
 
 static gboolean on_expose_dialog (GtkWidget *pWidget,
@@ -105,7 +107,8 @@ static gboolean on_expose_dialog (GtkWidget *pWidget,
 			glPopMatrix ();
 		}
 		
-		cairo_dock_notify (CAIRO_DOCK_RENDER_DIALOG, pDialog, NULL);
+		cairo_dock_notify_on_object (&myDialogsMgr, NOTIFICATION_RENDER_DIALOG, pDialog, NULL);
+		cairo_dock_notify_on_object (pDialog, NOTIFICATION_RENDER_DIALOG, pDialog, NULL);
 		
 		if (gdk_gl_drawable_is_double_buffered (pGlDrawable))
 			gdk_gl_drawable_swap_buffers (pGlDrawable);
@@ -119,7 +122,7 @@ static gboolean on_expose_dialog (GtkWidget *pWidget,
 		
 		if ((pExpose->area.x != 0 || pExpose->area.y != 0))
 		{
-			pCairoContext = cairo_dock_create_drawing_context_on_area (CAIRO_CONTAINER (pDialog), &pExpose->area, myDialogs.fDialogColor);
+			pCairoContext = cairo_dock_create_drawing_context_on_area (CAIRO_CONTAINER (pDialog), &pExpose->area, myDialogsParam.fDialogColor);
 		}
 		else
 		{
@@ -133,7 +136,8 @@ static gboolean on_expose_dialog (GtkWidget *pWidget,
 			cairo_restore (pCairoContext);
 		}
 		
-		cairo_dock_notify (CAIRO_DOCK_RENDER_DIALOG, pDialog, pCairoContext);
+		cairo_dock_notify_on_object (&myDialogsMgr, NOTIFICATION_RENDER_DIALOG, pDialog, pCairoContext);
+		cairo_dock_notify_on_object (pDialog, NOTIFICATION_RENDER_DIALOG, pDialog, pCairoContext);
 		
 		if (pDialog->fAppearanceCounter < 1.)
 		{
@@ -183,48 +187,61 @@ static gboolean on_configure_dialog (GtkWidget* pWidget,
 	CairoDialog *pDialog)
 {
 	//g_print ("%s (%dx%d, %d;%d) [%d]\n", __func__, pEvent->width, pEvent->height, pEvent->x, pEvent->y, pDialog->bPositionForced);
-	if (pEvent->width == CAIRO_DIALOG_MIN_SIZE && pEvent->height == CAIRO_DIALOG_MIN_SIZE && ! pDialog->bNoInput)
+	if (pEvent->width <= CAIRO_DIALOG_MIN_SIZE && pEvent->height <= CAIRO_DIALOG_MIN_SIZE && ! pDialog->bNoInput)
+	{
+		pDialog->container.bInside = FALSE;
 		return FALSE;
+	}
 	
-	int iWidth = pDialog->container.iWidth, iHeight = pDialog->container.iHeight;
-	//\____________ On recupere la taille du widget interactif qui a pu avoir change.
+	//\____________ get dialog size and position.
+	int iPrevWidth = pDialog->container.iWidth, iPrevHeight = pDialog->container.iHeight;
+	pDialog->container.iWidth = pEvent->width;
+	pDialog->container.iHeight = pEvent->height;
+	pDialog->container.iWindowPositionX = pEvent->x;
+	pDialog->container.iWindowPositionY = pEvent->y;
+	
+	//\____________ if an interactive widget is present, internal sizes may have changed.
 	if (pDialog->pInteractiveWidget != NULL)
 	{
+		int w = pDialog->iInteractiveWidth, h = pDialog->iInteractiveHeight;
 		GtkRequisition requisition;
 		gtk_widget_size_request (pDialog->pInteractiveWidget, &requisition);
 		pDialog->iInteractiveWidth = requisition.width;
 		pDialog->iInteractiveHeight = requisition.height;
 		//g_print ("  pInteractiveWidget : %dx%d\n", pDialog->iInteractiveWidth, pDialog->iInteractiveHeight);
-
-		pDialog->iBubbleWidth = MAX (pDialog->iMessageWidth, MAX (pDialog->iInteractiveWidth, pDialog->iButtonsWidth));
-		pDialog->iBubbleHeight = pDialog->iMessageHeight + pDialog->iInteractiveHeight + pDialog->iButtonsHeight;
-		//g_print (" -> iBubbleWidth: %d , iBubbleHeight : %d\n", pDialog->iBubbleWidth, pDialog->iBubbleHeight);
 		_cairo_dock_compute_dialog_sizes (pDialog);
-	}
-
-	if (iWidth != pEvent->width || iHeight != pEvent->height || (pDialog->bNoInput && ! pDialog->pShapeBitmap))
-	{
-		if ((pEvent->width != CAIRO_DIALOG_MIN_SIZE || pEvent->height != CAIRO_DIALOG_MIN_SIZE) && (pEvent->width < iWidth || pEvent->height < iHeight))
-		{
-			//g_print ("non, on a dit %dx%d !\n", pDialog->iBubbleWidth + pDialog->iLeftMargin + pDialog->iRightMargin,
-			//	pDialog->iBubbleHeight + pDialog->iTopMargin + pDialog->iBottomMargin + pDialog->iDistanceToDock);
-			gtk_window_resize (GTK_WINDOW (pDialog->container.pWidget),
-				pDialog->iBubbleWidth + pDialog->iLeftMargin + pDialog->iRightMargin,
-				pDialog->iBubbleHeight + pDialog->iTopMargin + pDialog->iBottomMargin + pDialog->iDistanceToDock);
-		}
-		pDialog->container.iWidth = pEvent->width;
-		pDialog->container.iHeight = pEvent->height;
 		
-		if (pDialog->bNoInput)
+		if (w != pDialog->iInteractiveWidth || h != pDialog->iInteractiveHeight)
 		{
-			_cairo_dock_set_dialog_input_shape (pDialog);
+			cairo_dock_replace_all_dialogs ();
+			/*Icon *pIcon = pDialog->pIcon;
+			if (pIcon != NULL)
+			{
+				CairoContainer *pContainer = cairo_dock_search_container_from_icon (pIcon);
+				cairo_dock_place_dialog (pDialog, pContainer);
+			}*/
 		}
 	}
-	else if (pEvent->y != pDialog->container.iWindowPositionY && !pDialog->bPositionForced)
+	//g_print ("dialog size: %dx%d / %dx%d\n", pEvent->width, pEvent->height, pDialog->iComputedWidth, pDialog->iComputedHeight);
+	
+	//\____________ set input shape if size has changed or if no shape yet.
+	if (pDialog->bNoInput && (iPrevWidth != pEvent->width || iPrevHeight != pEvent->height || ! pDialog->pShapeBitmap))
 	{
-		gtk_window_move (GTK_WINDOW (pDialog->container.pWidget), pDialog->container.iWindowPositionX, pDialog->container.iWindowPositionY);
-		pDialog->bPositionForced = TRUE;
+		_cairo_dock_set_dialog_input_shape (pDialog);
+		pDialog->container.bInside = FALSE;
 	}
+	
+	//\____________ force position for buggy WM (Compiz).
+	if (pDialog->iComputedWidth == pEvent->width && pDialog->iComputedHeight == pEvent->height && (pEvent->y != pDialog->iComputedPositionY || pEvent->x != pDialog->iComputedPositionX) && pDialog->bPositionForced == 3)
+	{
+		pDialog->container.bInside = FALSE;
+		cd_debug ("force to %d;%d", pDialog->iComputedPositionX, pDialog->iComputedPositionY);
+		/*gtk_window_move (GTK_WINDOW (pDialog->container.pWidget),
+			pDialog->iComputedPositionX,
+			pDialog->iComputedPositionY);
+		*/pDialog->bPositionForced ++;
+	}
+	
 	gtk_widget_queue_draw (pDialog->container.pWidget);  // les widgets internes peuvent avoir changer de taille sans que le dialogue n'en ait change, il faut donc redessiner tout le temps.
 
 	return FALSE;
@@ -281,14 +298,12 @@ static CairoDialog *_cairo_dock_create_empty_dialog (gboolean bInteractive)
 	pDialog->container.iType = CAIRO_DOCK_TYPE_DIALOG;
 	pDialog->iRefCount = 1;
 	pDialog->container.fRatio = 1.;
-	pDialog->container.iAnimationDeltaT = mySystem.iCairoAnimationDeltaT;
 
 	//\________________ On construit la fenetre du dialogue.
 	//GtkWidget* pWindow = gtk_window_new (bInteractiveWindow ? GTK_WINDOW_TOPLEVEL : GTK_WINDOW_POPUP);  // les popups ne prennent pas le focus. En fait, ils ne sont meme pas controles par le WM.
 	GtkWidget* pWindow = cairo_dock_init_container_no_opengl (CAIRO_CONTAINER (pDialog));
+	cairo_dock_install_notifications_on_object (pDialog, NB_NOTIFICATIONS_DIALOG);
 	
-	pDialog->container.pWidget = pWindow;
-
 	gtk_window_set_title (GTK_WINDOW (pWindow), "cairo-dock-dialog");
 	if (! bInteractive)
 		gtk_window_set_type_hint (GTK_WINDOW (pDialog->container.pWidget), GDK_WINDOW_TYPE_HINT_SPLASHSCREEN);  // pour ne pas prendre le focus.
@@ -296,7 +311,7 @@ static CairoDialog *_cairo_dock_create_empty_dialog (gboolean bInteractive)
 	gtk_widget_add_events (pWindow, GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
 	gtk_window_resize (GTK_WINDOW (pWindow), CAIRO_DIALOG_MIN_SIZE, CAIRO_DIALOG_MIN_SIZE);
 	gtk_window_set_keep_above (GTK_WINDOW (pWindow), TRUE);
-	gtk_widget_show_all (pWindow);
+	///gtk_widget_show_all (pWindow);
 	
 	return pDialog;
 }
@@ -307,7 +322,7 @@ static cairo_surface_t *_cairo_dock_create_dialog_text_surface (const gchar *cTe
 		return NULL;
 	
 	return cairo_dock_create_surface_from_text_full (cText,
-		(pTextDescription ? pTextDescription : &myDialogs.dialogTextDescription),
+		(pTextDescription ? pTextDescription : &myDialogsParam.dialogTextDescription),
 		1.,
 		0,
 		iTextWidth,
@@ -321,7 +336,7 @@ static cairo_surface_t *_cairo_dock_create_dialog_icon_surface (const gchar *cIm
 	if (cImageFilePath == NULL)
 		return NULL;
 	if (iDesiredSize == 0)
-		iDesiredSize = myDialogs.iDialogIconSize;
+		iDesiredSize = myDialogsParam.iDialogIconSize;
 	cairo_surface_t *pIconBuffer = NULL;
 	if (strcmp (cImageFilePath, "same icon") == 0)
 	{
@@ -335,6 +350,12 @@ static cairo_surface_t *_cairo_dock_create_dialog_icon_surface (const gchar *cIm
 				iWidth, iHeight,
 				iDesiredSize, iDesiredSize);
 		}
+		else if (pIcon && pIcon->cFileName)
+		{
+			pIconBuffer = cairo_dock_create_surface_from_image_simple (pIcon->cFileName,
+				iDesiredSize,
+				iDesiredSize);
+		}
 	}
 	else
 	{
@@ -366,6 +387,15 @@ static gboolean _cairo_dock_animate_dialog_text (CairoDialog *pDialog)
 	cairo_dock_damage_text_dialog (pDialog);
 	return TRUE;
 }
+static gboolean on_button_press_widget (GtkWidget *widget,
+	GdkEventButton *pButton,
+	CairoDialog *pDialog)
+{
+	cd_debug ("press button on widget");
+	// memorize the time when the user clicked on the widget.
+	pDialog->iButtonPressTime = pButton->time;
+	return FALSE;
+}
 CairoDialog *cairo_dock_new_dialog (CairoDialogAttribute *pAttribute, Icon *pIcon, CairoContainer *pContainer)
 {
 	//\________________ On cree un nouveau dialogue.
@@ -417,15 +447,15 @@ CairoDialog *cairo_dock_new_dialog (CairoDialogAttribute *pAttribute, Icon *pIco
 	}
 	
 	//\________________ On prend en compte les boutons.
-	pDialog->action_on_answer = pAttribute->pActionFunc;
 	pDialog->pUserData = pAttribute->pUserData;
 	pDialog->pFreeUserDataFunc = pAttribute->pFreeDataFunc;
 	if (pAttribute->cButtonsImage != NULL && pAttribute->pActionFunc != NULL)
 	{
 		int i;
 		for (i = 0; pAttribute->cButtonsImage[i] != NULL; i++);
-		pDialog->iNbButtons = i;
 		
+		pDialog->iNbButtons = i;
+		pDialog->action_on_answer = pAttribute->pActionFunc;
 		pDialog->pButtons = g_new0 (CairoDialogButton, pDialog->iNbButtons);
 		const gchar *cButtonImage;
 		for (i = 0; i < pDialog->iNbButtons; i++)
@@ -447,8 +477,8 @@ CairoDialog *cairo_dock_new_dialog (CairoDialogAttribute *pAttribute, Icon *pIco
 				else
 					cButtonPath = (gchar*)cButtonImage;
 				pDialog->pButtons[i].pSurface = cairo_dock_create_surface_from_image_simple (cButtonPath,
-					myDialogs.iDialogButtonWidth,
-					myDialogs.iDialogButtonHeight);
+					myDialogsParam.iDialogButtonWidth,
+					myDialogsParam.iDialogButtonHeight);
 				if (cButtonPath != cButtonImage)
 					g_free (cButtonPath);
 				///pDialog->pButtons[i].iTexture = cairo_dock_create_texture_from_surface (pDialog->pButtons[i].pSurface);
@@ -459,14 +489,23 @@ CairoDialog *cairo_dock_new_dialog (CairoDialogAttribute *pAttribute, Icon *pIco
 	{
 		pDialog->bNoInput = pAttribute->bNoInput;
 	}
-
+	
+	//\________________ Interactive dialogs are set modal, to be fixed.
+	if ((pDialog->pInteractiveWidget || pDialog->pButtons || pAttribute->iTimeLength == 0) && ! pDialog->bNoInput)
+	{
+		gtk_window_set_modal (GTK_WINDOW (pDialog->container.pWidget), TRUE);
+	}
+	pDialog->bHideOnClick = pAttribute->bHideOnClick;
+	
 	//\________________ On lui affecte un decorateur.
-	cairo_dock_set_dialog_decorator_by_name (pDialog, (pAttribute->cDecoratorName ? pAttribute->cDecoratorName : myDialogs.cDecoratorName));
+	cairo_dock_set_dialog_decorator_by_name (pDialog, (pAttribute->cDecoratorName ? pAttribute->cDecoratorName : myDialogsParam.cDecoratorName));
 	if (pDialog->pDecorator != NULL)
 		pDialog->pDecorator->set_size (pDialog);
 	
 	//\________________ Maintenant qu'on connait tout, on calcule les tailles des divers elements.
 	_cairo_dock_compute_dialog_sizes (pDialog);
+	pDialog->container.iWidth = pDialog->iBubbleWidth + pDialog->iLeftMargin + pDialog->iRightMargin;
+	pDialog->container.iHeight = pDialog->iBubbleHeight + pDialog->iTopMargin + pDialog->iBottomMargin + pDialog->iMinBottomGap;
 	
 	//\________________ On definit son orientation.
 	cairo_dock_set_dialog_orientation (pDialog, pContainer);  // renseigne aussi bDirectionUp, bIsHorizontal, et iHeight.
@@ -515,7 +554,7 @@ CairoDialog *cairo_dock_new_dialog (CairoDialogAttribute *pAttribute, Icon *pIco
 			FALSE,
 			0);
 		cd_debug (" pack -> ref = %d", pAttribute->pInteractiveWidget->object.parent_instance.ref_count);
-		cd_debug ("grab focus\n");
+		cd_debug ("grab focus");
 		gtk_window_present (GTK_WINDOW (pDialog->container.pWidget));
 		gtk_widget_grab_focus (pDialog->pInteractiveWidget);
 	}
@@ -528,13 +567,12 @@ CairoDialog *cairo_dock_new_dialog (CairoDialogAttribute *pAttribute, Icon *pIco
 	else
 		pDialog->pTopWidget = _cairo_dock_add_dialog_internal_box (pDialog, 0, pDialog->iTopMargin, TRUE);
 	
+	gtk_widget_show_all (pDialog->container.pWidget);
+	
 	if (pDialog->bNoInput)
 	{
 		_cairo_dock_set_dialog_input_shape (pDialog);
 	}
-	
-	gtk_widget_show_all (pDialog->container.pWidget);
-	
 	//\________________ On connecte les signaux utiles.
 	g_signal_connect (G_OBJECT (pDialog->container.pWidget),
 		"expose-event",
@@ -548,7 +586,12 @@ CairoDialog *cairo_dock_new_dialog (CairoDialogAttribute *pAttribute, Icon *pIco
 		"unmap-event",
 		G_CALLBACK (on_unmap_dialog),
 		pDialog);
-	
+	if (pDialog->pInteractiveWidget != NULL && pDialog->pButtons == NULL)  // the dialog has no button to be closed, so it can be closed by clicking on it. But some widget (like the GTK calendar) let pass the click to their parent (= the dialog), which then close it. To prevent this, we memorize the last click on the widget.
+		g_signal_connect (G_OBJECT (pDialog->pInteractiveWidget),
+			"button-press-event",
+			G_CALLBACK (on_button_press_widget),
+			pDialog);
+		
 	cairo_dock_launch_animation (CAIRO_CONTAINER (pDialog));
 	
 	return pDialog;
@@ -611,8 +654,6 @@ void cairo_dock_free_dialog (CairoDialog *pDialog)
 	if (pDialog->pUserData != NULL && pDialog->pFreeUserDataFunc != NULL)
 		pDialog->pFreeUserDataFunc (pDialog->pUserData);
 	
-	if (pDialog->pIcon && pDialog->pIcon->cParentDockName != NULL)
-		cairo_dock_dialog_window_destroyed ();
 	g_free (pDialog);
 }
 
@@ -624,78 +665,71 @@ static void _cairo_dock_dialog_calculate_aimed_point (Icon *pIcon, CairoContaine
 	if (CAIRO_DOCK_IS_DOCK (pContainer))
 	{
 		CairoDock *pDock = CAIRO_DOCK (pContainer);
-		if (pDock->iRefCount > 0 && ! GTK_WIDGET_VISIBLE (pDock->container.pWidget))  // sous-dock invisible.  // pDock->bAtBottom
+		if (pDock->iRefCount > 0 && ! GTK_WIDGET_VISIBLE (pContainer->pWidget))  // sous-dock invisible.
 		{
-			//g_print ("sous-dock invisible\n");
 			CairoDock *pParentDock = NULL;
 			Icon *pPointingIcon = cairo_dock_search_icon_pointing_on_dock (pDock, &pParentDock);
 			_cairo_dock_dialog_calculate_aimed_point (pPointingIcon, CAIRO_CONTAINER (pParentDock), iX, iY, bRight, bIsHorizontal, bDirectionUp, fAlign);
 		}
-		else/* if (pDock->iRefCount == 0)*/  // un dock principal au repos.  // && pDock->bAtBottom
+		else  // dock principal ou sous-dock wisible.
 		{
-			//g_print ("dock %d\n", pDock->iRefCount);
-			*bIsHorizontal = (pDock->container.bIsHorizontal == CAIRO_DOCK_HORIZONTAL);
+			*bIsHorizontal = (pContainer->bIsHorizontal == CAIRO_DOCK_HORIZONTAL);
 			int dy;
 			if (pDock->iInputState == CAIRO_DOCK_INPUT_ACTIVE)
 				dy = 0;
 			else if (cairo_dock_is_hidden (pDock))
-					dy = pDock->container.iHeight;
+				dy = pContainer->iHeight-1;  // on laisse 1 pixels pour pouvoir sortir du dialogue avant de toucher le bord de l'ecran, et ainsi le faire se replacer, lorsqu'on fait apparaitre un dock en auto-hide.
 			else
-				dy = pDock->container.iHeight - pDock->iMinDockHeight;
-			if (pDock->container.bIsHorizontal)
+				dy = pContainer->iHeight - pDock->iMinDockHeight;
+			if (pContainer->bIsHorizontal)
 			{
-				*bRight = (pIcon ? pIcon->fXAtRest > pDock->fFlatDockWidth / 2 : TRUE);
-				*bDirectionUp = pDock->container.bDirectionUp;
-				
-				//g_print ("y = %d + %d\n", pDock->container.iWindowPositionY, dy);
+				*bRight = (pIcon ? pIcon->fXAtRest < pDock->fFlatDockWidth / 2 : TRUE);
+				*bDirectionUp = pContainer->bDirectionUp;
 				
 				if (*bDirectionUp)
-					*iY = pDock->container.iWindowPositionY + dy;
+					*iY = pContainer->iWindowPositionY + dy;
 				else
-					*iY = pDock->container.iWindowPositionY + pDock->container.iHeight - dy;
+					*iY = pContainer->iWindowPositionY + pContainer->iHeight - dy;
 			}
 			else
 			{
-				*bRight = (pDock->container.iWindowPositionY > g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL] / 2);
+				*bRight = (pContainer->iWindowPositionY > g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL] / 2);
 				*bDirectionUp = (pIcon ? pIcon->fXAtRest > pDock->fFlatDockWidth / 2 : TRUE);
-				///*iY = (! (*bRight) ? pDock->container.iWindowPositionY : pDock->container.iWindowPositionY + pDock->container.iHeight) + (pDock->container.bDirectionUp ? dy : -dy);
-				*iY = (pDock->container.bDirectionUp ?
-					pDock->container.iWindowPositionY + dy :
-					pDock->container.iWindowPositionY + pDock->container.iHeight - dy);
-				//g_print ("dock vertical -> y=%d, right = %d\n", *iY, *bRight);
+				*iY = (pContainer->bDirectionUp ?
+					pContainer->iWindowPositionY + dy :
+					pContainer->iWindowPositionY + pContainer->iHeight - dy);
 			}
 			
 			if (cairo_dock_is_hidden (pDock))
 			{
-				*iX = pDock->container.iWindowPositionX +
-					(pIcon ? (pIcon->fXAtRest + pIcon->fWidth * (.5 + (*bRight ? .2 : -.2) * 2*(.5-fAlign))) / pDock->fFlatDockWidth * pDock->iMaxDockWidth : 0);
-				//cd_debug ("placement sur un dock cache -> %d", *iX);
+				*iX = pContainer->iWindowPositionX +
+					(pIcon ? (pIcon->fXAtRest + pIcon->fWidth/2) / pDock->fFlatDockWidth * pDock->iMaxDockWidth : 0);
 			}
 			else
 			{
-				*iX = pDock->container.iWindowPositionX +
-					(pIcon ? pIcon->fDrawX + pIcon->fWidth * pIcon->fScale * (.5 + (*bRight ? .2 : -.2) * 2*(.5-fAlign)) : 0);
-				//g_print ("dock not hidden -> x=%d\n", *iX);
+				*iX = pContainer->iWindowPositionX +
+					(pIcon ? pIcon->fDrawX + pIcon->fWidth * pIcon->fScale/2 : 0);
 			}
 		}
 	}
 	else if (CAIRO_DOCK_IS_DESKLET (pContainer))
 	{
 		CairoDesklet *pDesklet = CAIRO_DESKLET (pContainer);
-		*bDirectionUp = (pDesklet->container.iWindowPositionY > g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] / 2);
-		*bIsHorizontal = (pDesklet->container.iWindowPositionX > 50 && pDesklet->container.iWindowPositionX + pDesklet->container.iHeight < g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] - 50);
+		*bDirectionUp = (pContainer->iWindowPositionY > g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] / 2);
+		///*bIsHorizontal = (pContainer->iWindowPositionX > 50 && pContainer->iWindowPositionX + pContainer->iHeight < g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] - 50);
+		*bIsHorizontal = TRUE;
 		
 		if (*bIsHorizontal)
 		{
-			*bRight = (pDesklet->container.iWindowPositionX > g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] / 2);
-			*iX = pDesklet->container.iWindowPositionX + pDesklet->container.iWidth * (*bRight ? .7 : .3);
-			*iY = (*bDirectionUp ? pDesklet->container.iWindowPositionY : pDesklet->container.iWindowPositionY + pDesklet->container.iHeight);
+			*bRight = (pContainer->iWindowPositionX + pContainer->iWidth/2 < g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] / 2);
+			*iX = pContainer->iWindowPositionX + pContainer->iWidth * (*bRight ? .7 : .3);
+			*iY = (*bDirectionUp ? pContainer->iWindowPositionY : pContainer->iWindowPositionY + pContainer->iHeight);
 		}
 		else
 		{
-			*bRight = (pDesklet->container.iWindowPositionX < g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] / 2);
-			*iY = pDesklet->container.iWindowPositionX + pDesklet->container.iWidth * (*bRight ? 1 : 0);
-			*iX =pDesklet->container.iWindowPositionY + pDesklet->container.iHeight / 2;
+			*bRight = (pContainer->iWindowPositionX < g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] / 2);
+			*iY = pContainer->iWindowPositionX + pContainer->iWidth * (*bRight ? 1 : 0);
+			*iX =pContainer->iWindowPositionY + pContainer->iHeight / 2;
 		}
 	}
 }
@@ -705,7 +739,7 @@ void cairo_dock_set_dialog_orientation (CairoDialog *pDialog, CairoContainer *pC
 {
 	if (pContainer != NULL && pDialog->pIcon != NULL)
 	{
-		_cairo_dock_dialog_calculate_aimed_point (pDialog->pIcon, pContainer, &pDialog->iAimedX, &pDialog->iAimedY, &pDialog->bRight, &pDialog->bTopBottomDialog, &pDialog->container.bDirectionUp, pDialog->fAlign);		
+		_cairo_dock_dialog_calculate_aimed_point (pDialog->pIcon, pContainer, &pDialog->iAimedX, &pDialog->iAimedY, &pDialog->bRight, &pDialog->bTopBottomDialog, &pDialog->container.bDirectionUp, pDialog->fAlign);
 	}
 	else
 	{
@@ -724,6 +758,15 @@ GtkWidget *cairo_dock_steal_widget_from_its_container (GtkWidget *pWidget)
 		g_object_ref (G_OBJECT (pWidget));
 		gtk_container_remove (GTK_CONTAINER (pContainer), pWidget);
 		cd_debug (" -> %d", pWidget->object.parent_instance.ref_count);
+		
+		// if we were monitoring the click events on the widget, stop it.
+		g_signal_handlers_disconnect_matched (pWidget,
+			G_SIGNAL_MATCH_FUNC,
+			0,
+			0,
+			NULL,
+			on_button_press_widget,
+			NULL);
 	}
 	return pWidget;
 }
@@ -822,8 +865,8 @@ void cairo_dock_set_dialog_message_printf (CairoDialog *pDialog, const gchar *cM
 
 void cairo_dock_set_dialog_icon (CairoDialog *pDialog, const gchar *cImageFilePath)
 {
-	cairo_surface_t *pNewIconSurface = cairo_dock_create_surface_for_square_icon (cImageFilePath, myDialogs.iDialogIconSize);
-	int iNewIconSize = (pNewIconSurface != NULL ? myDialogs.iDialogIconSize : 0);
+	cairo_surface_t *pNewIconSurface = cairo_dock_create_surface_for_square_icon (cImageFilePath, myDialogsParam.iDialogIconSize);
+	int iNewIconSize = (pNewIconSurface != NULL ? myDialogsParam.iDialogIconSize : 0);
 	
 	cairo_dock_set_new_dialog_icon_surface (pDialog, pNewIconSurface, iNewIconSize);
 }
