@@ -25,8 +25,8 @@
 
 #include "cairo-dock-struct.h"
 #include "cairo-dock-desktop-file-factory.h"
-#include "cairo-dock-load.h"
-#include "cairo-dock-icons.h"
+#include "cairo-dock-image-buffer.h"
+#include "cairo-dock-icon-factory.h"
 #include "cairo-dock-container.h"
 G_BEGIN_DECLS
 
@@ -78,6 +78,8 @@ struct _CairoDockRenderer {
 	CairoDockGLRenderFunc render_opengl;
 	/// function that computes the position of the dock when it's a sub-dock.
 	CairoDockSetSubDockPositionFunc set_subdock_position;
+	/// function called when the renderer is unset from the dock.
+	CairoDockRenderFreeDataFunc free_data;
 	/// TRUE if the view uses the OpenGL stencil buffer.
 	gboolean bUseStencil;
 	/// TRUE is the view uses reflects.
@@ -88,8 +90,6 @@ struct _CairoDockRenderer {
 	gchar *cReadmeFilePath;
 	/// path to a preview image.
 	gchar *cPreviewFilePath;
-	/// function called when the renderer is unset from the dock.
-	CairoDockRenderFreeDataFunc free_data;
 };
 
 typedef enum {
@@ -204,6 +204,12 @@ struct _CairoDock {
 	guint iSidUpdateWMIcons;
 	/// Source ID for hiding back the dock.
 	guint iSidHideBack;
+	/// Source ID for loading the background.
+	guint iSidLoadBg;
+	/// Source ID to destroy an empty main dock.
+	guint iSidDestroyEmptyDock;
+	/// Source ID for shrinking down the dock after a mouse event.
+	guint iSidTestMouseOutside;
 	
 	//\_______________ Renderer and fields set by it.
 	// nom de la vue, utile pour (re)charger les fonctions de rendu posterieurement a la creation du dock.
@@ -257,15 +263,10 @@ struct _CairoDock {
 	gdouble fBgColorDark[4];
 	/// Background image buffer of the dock.
 	CairoDockImageBuffer backgroundBuffer;
-	/// Source ID for loading the background.
-	guint iSidLoadBg;
 	
-	gboolean bPreventDraggingIcons;  // whether icons in the dock can be dragged with the mouse (inside and outside of the dock).
+	// whether icons in the dock can be dragged with the mouse (inside and outside of the dock).
+	gboolean bPreventDraggingIcons;
 	
-	/// Source ID to destroy an empty main dock.
-	guint iSidDestroyEmptyDock;
-	/// Source ID for shrinking down the dock after a mouse event.
-	guint iSidTestMouseOutside;
 	gchar reserved[4];
 };
 
@@ -307,7 +308,7 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 * @param bUpdateSize TRUE to update the size of the dock after the insertion.
 * @param bAnimated TRUE to arm the icon's animation for insertion.
 */
-#define cairo_dock_insert_icon_in_dock(icon, pDock, bUpdateSize, bAnimated) cairo_dock_insert_icon_in_dock_full (icon, pDock, bUpdateSize, bAnimated, myIcons.iSeparateIcons, NULL)
+#define cairo_dock_insert_icon_in_dock(icon, pDock, bUpdateSize, bAnimated) cairo_dock_insert_icon_in_dock_full (icon, pDock, bUpdateSize, bAnimated, myIconsParam.iSeparateIcons, NULL)
 
 /** Detach an icon from its dock, removing the unnecessary separators. The icon is not destroyed, and can be directly re-inserted in another container; it keeps its sub-dock, but looses its dialogs. Do nothing if the icon doesn't exist inside the dock.
 *@param icon the icon to detach.
@@ -345,7 +346,7 @@ void cairo_dock_remove_automatic_separators (CairoDock *pDock);
 */
 void cairo_dock_insert_separators_in_dock (CairoDock *pDock);
 
-Icon *cairo_dock_add_new_launcher_by_uri_or_type (const gchar *cExternDesktopFileURI, CairoDockDesktopFileType iType, CairoDock *pReceivingDock, double fOrder, CairoDockIconType iGroup);
+Icon *cairo_dock_add_new_launcher_by_uri_or_type (const gchar *cExternDesktopFileURI, CairoDockDesktopFileType iType, CairoDock *pReceivingDock, double fOrder, CairoDockIconGroup iGroup);
 
 /** Add a launcher from a common desktop file : create and add the corresponding .desktop file with the others, load the corresponding icon, and insert it inside a dock with an animtion.
 *@param cExternDesktopFileURI path to a desktop file.
@@ -359,6 +360,7 @@ Icon *cairo_dock_add_new_launcher_by_uri_or_type (const gchar *cExternDesktopFil
 *@param iType type of the launcher.
 *@param pReceivingDock the dock that will hold the new launcher.
 *@param fOrder the order of the icon inside the dock.
+*@param iGroup the group it will belong to
 *@return the newly created Icon corresponding to the type, or NULL if an error occured.
 */
 #define cairo_dock_add_new_launcher_by_type(iType, pReceivingDock, fOrder, iGroup) cairo_dock_add_new_launcher_by_uri_or_type (NULL, iType, pReceivingDock, fOrder, iGroup)
