@@ -24,9 +24,9 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 
-#include "../config.h"
+#include "gldi-config.h"
 #include "cairo-dock-struct.h"
-#include "cairo-dock-modules.h"
+#include "cairo-dock-module-factory.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-gui-factory.h"
 #include "cairo-dock-keyfile-utilities.h"
@@ -37,182 +37,26 @@
 #include "cairo-dock-container.h"
 #include "cairo-dock-applications-manager.h"
 #include "cairo-dock-launcher-factory.h"
-#include "cairo-dock-load.h"
-#include "cairo-dock-internal-accessibility.h"
+#include "cairo-dock-image-buffer.h"
 #include "cairo-dock-desktop-file-factory.h"
+#include "cairo-dock-X-manager.h"
+#define _MANAGER_DEF_
 #include "cairo-dock-gui-manager.h"
 
-#define CAIRO_DOCK_FRAME_MARGIN 6
-
 extern CairoDock *g_pMainDock;
 extern gchar *g_cCairoDockDataDir;
+extern CairoDockDesktopGeometry g_desktopGeometry;
 
 static CairoDockGuiBackend *s_pGuiBackend = NULL;
-static CairoDockLauncherGuiBackend *s_pLauncherGuiBackend = NULL;
 
-  //////////////////////////
- // MAIN DOCK VISIBILITY //
-//////////////////////////
+  /////////////////
+ // GUI BACKEND //
+/////////////////
 
-static int iNbConfigDialogs = 0;
-int cairo_dock_get_nb_dialog_windows (void)
+void cairo_dock_register_gui_backend (CairoDockGuiBackend *pBackend)
 {
-	return iNbConfigDialogs;
-}
-
-void cairo_dock_dialog_window_destroyed (void)
-{
-	/**iNbConfigDialogs --;
-	if (iNbConfigDialogs <= 0)
-	{
-		iNbConfigDialogs = 0;
-		if (g_pMainDock != NULL)  // peut arriver au 1er lancement.
-			cairo_dock_pop_down (g_pMainDock);
-	}*/
-	//g_print ("iNbConfigDialogs <- %d\n", iNbConfigDialogs);
-}
-
-void cairo_dock_dialog_window_created (void)
-{
-	/**iNbConfigDialogs ++;
-	//g_print ("iNbConfigDialogs <- %d\n", iNbConfigDialogs);
-	if (g_pMainDock != NULL && cairo_dock_search_window_covering_dock (g_pMainDock, FALSE, TRUE) == NULL)  // peut etre NULL au 1er lancement.
-		cairo_dock_pop_up (g_pMainDock);*/
-}
-
-
-  //////////////////////////
- // DYNAMIC CONFIG PANEL //
-//////////////////////////
-
-CairoDockGroupKeyWidget *cairo_dock_get_group_key_widget_from_name (const gchar *cGroupName, const gchar *cKeyName)
-{
-	if (s_pGuiBackend && s_pGuiBackend->get_widget_from_name)
-	{
-		return s_pGuiBackend->get_widget_from_name (cGroupName, cKeyName);
-	}
-	return NULL;
-}
-
-GtkWidget *cairo_dock_get_widget_from_name (const gchar *cGroupName, const gchar *cKeyName)
-{
-	CairoDockGroupKeyWidget *pGroupKeyWidget = cairo_dock_get_group_key_widget_from_name (cGroupName, cKeyName);
-	if (pGroupKeyWidget != NULL && pGroupKeyWidget->pSubWidgetList != NULL)
-		return pGroupKeyWidget->pSubWidgetList->data;
-	return NULL;
-}
-
-void cairo_dock_reload_current_module_widget_full (CairoDockModuleInstance *pInstance, int iShowPage)
-{
-	g_return_if_fail (pInstance != NULL);
-	if (pInstance->pModule->pVisitCard->cInternalModule != NULL)
-	{
-		cairo_dock_show_module_gui (pInstance->pModule->pVisitCard->cInternalModule);
-	}
-	else
-	{
-		cairo_dock_show_module_instance_gui (pInstance, iShowPage);
-	}
-	/**g_return_if_fail (s_pCurrentGroupWidget != NULL && s_pCurrentGroup != NULL && cairo_dock_get_current_widget_list () != NULL);
-	
-	int iNotebookPage = (GTK_IS_NOTEBOOK (s_pCurrentGroupWidget) ? 
-		(iShowPage >= 0 ?
-			iShowPage :
-			gtk_notebook_get_current_page (GTK_NOTEBOOK (s_pCurrentGroupWidget))) :
-		-1);
-	
-	gtk_widget_destroy (s_pCurrentGroupWidget);
-	s_pCurrentGroupWidget = NULL;
-	
-	cairo_dock_reset_current_widget_list ();
-	
-	CairoDockModule *pModule = cairo_dock_find_module_from_name (s_pCurrentGroup->cGroupName);
-	GtkWidget *pWidget;
-	if (pModule != NULL)
-	{
-		pWidget = cairo_dock_present_group_widget (pModule->cConfFilePath, s_pCurrentGroup, FALSE, pInstance);
-	}
-	else
-	{
-		pWidget = cairo_dock_present_group_widget (g_cConfFile, s_pCurrentGroup, TRUE, NULL);
-	}
-	if (iNotebookPage != -1)
-	{
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (s_pCurrentGroupWidget), iNotebookPage);
-	}*/
-}
-
-
-void cairo_dock_deactivate_module_in_gui (const gchar *cModuleName)
-{
-	if (s_pGuiBackend && s_pGuiBackend->deactivate_module_in_gui)
-		s_pGuiBackend->deactivate_module_in_gui (cModuleName);
-}
-
-static gboolean _cairo_dock_module_is_opened (CairoDockModuleInstance *pModuleInstance)
-{
-	if (s_pGuiBackend && s_pGuiBackend->module_is_opened)
-		return s_pGuiBackend->module_is_opened (pModuleInstance);
-	else
-		return FALSE;
-}
-
-void cairo_dock_update_desklet_size_in_gui (CairoDockModuleInstance *pModuleInstance, int iWidth, int iHeight)
-{
-	if (_cairo_dock_module_is_opened (pModuleInstance))  // on est en train d'editer ce module dans le panneau de conf.
-	{
-		CairoDockGroupKeyWidget *pGroupKeyWidget = cairo_dock_get_group_key_widget_from_name ("Desklet", "size");
-		GtkWidget *pOneWidget;
-		
-		if (pGroupKeyWidget != NULL && pGroupKeyWidget->pSubWidgetList)
-		{
-			pOneWidget = pGroupKeyWidget->pSubWidgetList->data;
-			g_signal_handlers_block_matched (pOneWidget,
-				(GSignalMatchType) G_SIGNAL_MATCH_FUNC,
-				0, 0, NULL, _cairo_dock_set_value_in_pair, NULL);
-			gtk_spin_button_set_value (GTK_SPIN_BUTTON (pOneWidget), iWidth);
-			g_signal_handlers_unblock_matched (pOneWidget,
-				(GSignalMatchType) G_SIGNAL_MATCH_FUNC,
-				0, 0, NULL, _cairo_dock_set_value_in_pair, NULL);
-			
-			if (pGroupKeyWidget->pSubWidgetList->next != NULL)
-			{
-				pOneWidget = pGroupKeyWidget->pSubWidgetList->next->data;
-				g_signal_handlers_block_matched (pOneWidget,
-					(GSignalMatchType) G_SIGNAL_MATCH_FUNC,
-					0, 0, NULL, _cairo_dock_set_value_in_pair, NULL);
-				gtk_spin_button_set_value (GTK_SPIN_BUTTON (pOneWidget), iHeight);
-				g_signal_handlers_unblock_matched (pOneWidget,
-					(GSignalMatchType) G_SIGNAL_MATCH_FUNC,
-					0, 0, NULL, _cairo_dock_set_value_in_pair, NULL);
-			}
-		}
-		
-	}
-}
-
-void cairo_dock_update_desklet_position_in_gui (CairoDockModuleInstance *pModuleInstance, int x, int y)
-{
-	if (_cairo_dock_module_is_opened (pModuleInstance))  // on est en train d'editer ce module dans le panneau de conf.
-	{
-		GtkWidget *pOneWidget;
-		pOneWidget = cairo_dock_get_widget_from_name ("Desklet", "x position");
-		if (pOneWidget != NULL)
-			gtk_spin_button_set_value (GTK_SPIN_BUTTON (pOneWidget), x);
-		pOneWidget = cairo_dock_get_widget_from_name ("Desklet", "y position");
-		if (pOneWidget != NULL)
-			gtk_spin_button_set_value (GTK_SPIN_BUTTON (pOneWidget), y);
-	}
-}
-
-void cairo_dock_update_desklet_detached_state_in_gui (CairoDockModuleInstance *pModuleInstance, gboolean bIsDetached)
-{
-	if (_cairo_dock_module_is_opened (pModuleInstance))  // on est en train d'editer ce module dans le panneau de conf.
-	{
-		GtkWidget *pOneWidget = cairo_dock_get_widget_from_name ("Desklet", "initially detached");
-		if (pOneWidget != NULL)
-			gtk_toggle_button_set_active  (GTK_TOGGLE_BUTTON (pOneWidget), bIsDetached);
-	}
+	g_free (s_pGuiBackend);
+	s_pGuiBackend = pBackend;
 }
 
 
@@ -248,40 +92,27 @@ void cairo_dock_set_status_message_printf (GtkWidget *pWindow, const gchar *cFor
 }
 
 
-  /////////////////
- // GUI BACKEND //
-/////////////////
-
-void cairo_dock_register_gui_backend (CairoDockGuiBackend *pBackend)
+CairoDockGroupKeyWidget *cairo_dock_get_group_key_widget_from_name (CairoDockModuleInstance *pModuleInstance, const gchar *cGroupName, const gchar *cKeyName)
 {
-	g_free (s_pGuiBackend);
-	s_pGuiBackend = pBackend;
+	if (s_pGuiBackend && s_pGuiBackend->get_widget_from_name)
+	{
+		return s_pGuiBackend->get_widget_from_name (pModuleInstance, cGroupName, cKeyName);
+	}
+	return NULL;
 }
 
-GtkWidget *cairo_dock_show_main_gui (void)
+GtkWidget *cairo_dock_get_widget_from_name (CairoDockModuleInstance *pModuleInstance, const gchar *cGroupName, const gchar *cKeyName)
 {
-	GtkWidget *pWindow = NULL;
-	if (s_pGuiBackend && s_pGuiBackend->show_main_gui)
-		pWindow = s_pGuiBackend->show_main_gui ();
-	if (pWindow && g_pMainDock != NULL)  // evitons d'empieter sur le main dock.
-	{
-		if (g_pMainDock->container.bIsHorizontal)
-		{
-			if (g_pMainDock->container.bDirectionUp)
-				gtk_window_move (GTK_WINDOW (pWindow), 0, 0);
-			else
-				gtk_window_move (GTK_WINDOW (pWindow), 0, g_pMainDock->iMinDockHeight+10);
-		}
-		else
-		{
-			if (g_pMainDock->container.bDirectionUp)
-				gtk_window_move (GTK_WINDOW (pWindow), 0, 0);
-			else
-				gtk_window_move (GTK_WINDOW (pWindow), g_pMainDock->iMinDockHeight+10, 0);
-		}
-	}
-	
-	return pWindow;
+	CairoDockGroupKeyWidget *pGroupKeyWidget = cairo_dock_get_group_key_widget_from_name (pModuleInstance, cGroupName, cKeyName);
+	if (pGroupKeyWidget != NULL && pGroupKeyWidget->pSubWidgetList != NULL)
+		return pGroupKeyWidget->pSubWidgetList->data;
+	return NULL;
+}
+
+void cairo_dock_reload_current_widget_full (CairoDockModuleInstance *pModuleInstance, int iShowPage)
+{
+	if (s_pGuiBackend && s_pGuiBackend->reload_current_widget)
+		s_pGuiBackend->reload_current_widget (pModuleInstance, iShowPage);
 }
 
 void cairo_dock_show_module_instance_gui (CairoDockModuleInstance *pModuleInstance, int iShowPage)
@@ -290,18 +121,6 @@ void cairo_dock_show_module_instance_gui (CairoDockModuleInstance *pModuleInstan
 		s_pGuiBackend->show_module_instance_gui (pModuleInstance, iShowPage);
 }
 
-void cairo_dock_show_module_gui (const gchar *cModuleName)
-{
-	if (s_pGuiBackend && s_pGuiBackend->show_module_gui)
-		s_pGuiBackend->show_module_gui (cModuleName);
-}
-
-void cairo_dock_close_gui (void)
-{
-	if (s_pGuiBackend && s_pGuiBackend->close_gui)
-		s_pGuiBackend->close_gui ();
-}
-
 
   ////////////////
  // NORMAL GUI //
@@ -329,8 +148,6 @@ static gboolean on_delete_generic_gui (GtkWidget *pWidget, GdkEvent *event, GMai
 	gchar *cConfFilePath = g_object_get_data (G_OBJECT (pWidget), "conf-file");
 	g_free (cConfFilePath);
 	
-	cairo_dock_dialog_window_destroyed ();
-	
 	return (pBlockingLoop != NULL);  // TRUE <=> ne pas detruire la fenetre.
 }
 
@@ -414,7 +231,7 @@ GtkWidget *cairo_dock_build_generic_gui_window (const gchar *cTitle, int iWidth,
 {
 	//\_____________ On construit la fenetre.
 	GtkWidget *pMainWindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_icon_from_file (GTK_WINDOW (pMainWindow), CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON, NULL);
+	gtk_window_set_icon_from_file (GTK_WINDOW (pMainWindow), GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON, NULL);
 	if (cTitle != NULL)
 		gtk_window_set_title (GTK_WINDOW (pMainWindow), cTitle);
 	
@@ -468,10 +285,11 @@ GtkWidget *cairo_dock_build_generic_gui_window (const gchar *cTitle, int iWidth,
 		0);
 	g_object_set_data (G_OBJECT (pMainWindow), "status-bar", pStatusBar);
 	
-	gtk_window_resize (GTK_WINDOW (pMainWindow), iWidth, iHeight);
+	gtk_window_resize (GTK_WINDOW (pMainWindow),
+		MIN (iWidth, g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]),
+		MIN (iHeight, g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - (g_pMainDock && g_pMainDock->container.bIsHorizontal ? g_pMainDock->iMaxDockHeight : 0)));
 	
 	gtk_widget_show_all (pMainWindow);
-	cairo_dock_dialog_window_created ();
 	
 	int iResult = 0;
 	if (pAction != NULL)
@@ -514,11 +332,6 @@ GtkWidget *cairo_dock_build_generic_gui_full (const gchar *cConfFilePath, const
 	g_object_set_data (G_OBJECT (pMainWindow), "save-widget", save_custom_widgets);
 	g_object_set_data (G_OBJECT (pMainWindow), "load-widget", load_custom_widgets);
 	
-	if (load_custom_widgets)  // a faire apres avoir mis "widget-list".
-		load_custom_widgets (pMainWindow, pKeyFile);
-	
-	g_key_file_free (pKeyFile);
-	
 	//\_____________ On l'insere dans la fenetre.
 	GtkWidget *pMainVBox = gtk_bin_get_child (GTK_BIN (pMainWindow));
 	gtk_box_pack_start (GTK_BOX (pMainVBox),
@@ -526,8 +339,16 @@ GtkWidget *cairo_dock_build_generic_gui_full (const gchar *cConfFilePath, const
 		TRUE,
 		TRUE,
 		0);
+	
+	//\_____________ On complete le widget.
+	if (load_custom_widgets)  // a faire apres avoir mis "widget-list" et insere dans la fenetre.
+		load_custom_widgets (pMainWindow, pKeyFile);
+	
+	g_key_file_free (pKeyFile);
+	
 	gtk_widget_show_all (pMainWindow);
 	
+	//\_____________ si pas de callback, on bloque.
 	int iResult = 0;
 	if (pAction == NULL)  // on bloque.
 	{
@@ -535,6 +356,7 @@ GtkWidget *cairo_dock_build_generic_gui_full (const gchar *cConfFilePath, const
 		GList *w = g_list_last (children);
 		g_return_val_if_fail (w != NULL, FALSE);
 		GtkWidget *pButtonsHBox = w->data;
+		g_list_free (children);
 		
 		GtkWidget *pOkButton = gtk_button_new_from_stock (GTK_STOCK_OK);
 		g_signal_connect (G_OBJECT (pOkButton), "clicked", G_CALLBACK(on_click_generic_ok), pMainWindow);
@@ -586,6 +408,7 @@ void cairo_dock_reload_generic_gui (GtkWidget *pWindow)
 	GList *children = gtk_container_get_children (GTK_CONTAINER (pMainVBox));
 	g_return_if_fail (children != NULL);
 	GtkWidget *pNoteBook = children->data;
+	g_list_free (children);
 	gtk_widget_destroy (pNoteBook);
 	
 	gchar *cConfFilePath = g_object_get_data (G_OBJECT (pWindow), "conf-file");
@@ -603,50 +426,17 @@ void cairo_dock_reload_generic_gui (GtkWidget *pWindow)
 	g_object_set_data (G_OBJECT (pWindow), "widget-list", pWidgetList);
 	g_object_set_data (G_OBJECT (pWindow), "garbage", pDataGarbage);
 	
+	gtk_box_pack_start (GTK_BOX (pMainVBox),
+		pNoteBook,
+		TRUE,
+		TRUE,
+		0);
+	
 	CairoDockLoadCustomWidgetFunc load_custom_widgets = g_object_get_data (G_OBJECT (pWindow), "load-widget");
 	if (load_custom_widgets)  // a faire apres avoir mis "widget-list".
 		load_custom_widgets (pWindow, pKeyFile);
 	
 	g_key_file_free (pKeyFile);
 	
-	gtk_box_pack_start (GTK_BOX (pMainVBox),
-		pNoteBook,
-		TRUE,
-		TRUE,
-		0);
 	gtk_widget_show_all (pNoteBook);
 }
-
-
-  //////////////////////////
- // LAUNCHER GUI BACKEND //
-//////////////////////////
-
-void cairo_dock_register_launcher_gui_backend (CairoDockLauncherGuiBackend *pBackend)
-{
-	g_free (s_pLauncherGuiBackend);
-	s_pLauncherGuiBackend = pBackend;
-}
-
-GtkWidget *cairo_dock_build_launcher_gui (Icon *pIcon)
-{
-	if (s_pLauncherGuiBackend && s_pLauncherGuiBackend->show_gui)
-		s_pLauncherGuiBackend->show_gui (pIcon);
-}
-
-static guint s_iSidRefreshGUI = 0;
-static gboolean _refresh_launcher_gui (gpointer data)
-{
-	if (s_pLauncherGuiBackend && s_pLauncherGuiBackend->refresh_gui)
-		s_pLauncherGuiBackend->refresh_gui ();
-	
-	s_iSidRefreshGUI = 0;
-	return FALSE;
-}
-void cairo_dock_trigger_refresh_launcher_gui (void)
-{
-	if (s_iSidRefreshGUI != 0)
-		return;
-	
-	s_iSidRefreshGUI = g_idle_add ((GSourceFunc) _refresh_launcher_gui, NULL);
-}
