@@ -31,36 +31,27 @@
 #include <cairo-glitz.h>
 #endif
 
-#include "cairo-dock-load.h"
-#include "cairo-dock-icons.h"
-#include "cairo-dock-draw.h"
-#include "cairo-dock-dock-factory.h"
+#include "cairo-dock-icon-facility.h"  // cairo_dock_compare_icons_order
+#include "cairo-dock-config.h"  // cairo_dock_update_conf_file
 #include "cairo-dock-surface-factory.h"
-#include "cairo-dock-backends-manager.h"
-#include "cairo-dock-file-manager.h"
+#include "cairo-dock-backends-manager.h"  // cairo_dock_set_renderer
 #include "cairo-dock-log.h"
 #include "cairo-dock-dock-manager.h"
-#include "cairo-dock-applications-manager.h"
-#include "cairo-dock-class-manager.h"
+#include "cairo-dock-applications-manager.h"  // myTaskbarParam.bMixLauncherAppli
+#include "cairo-dock-class-manager.h"  // cairo_dock_inhibite_class
 #include "cairo-dock-keyfile-utilities.h"
-#include "cairo-dock-internal-system.h"
-#include "cairo-dock-internal-icons.h"
-#include "cairo-dock-internal-labels.h"
-#include "cairo-dock-internal-taskbar.h"
-#include "cairo-dock-themes-manager.h"
-#include "cairo-dock-dock-facility.h"
-#include "cairo-dock-gui-manager.h"
-#include "cairo-dock-emblem.h"
-#include "cairo-dock-launcher-factory.h"
-#include "cairo-dock-internal-indicators.h"
-#include "cairo-dock-separator-manager.h"
+#include "cairo-dock-themes-manager.h"  // cairo_dock_mark_current_theme_as_modified
+#include "cairo-dock-dock-facility.h"  // cairo_dock_update_dock_size
+///#include "cairo-dock-gui-manager.h"  // cairo_dock_trigger_refresh_launcher_gui
+#include "cairo-dock-animations.h"  // cairo_dock_launch_animation
+#include "cairo-dock-launcher-factory.h"  // cairo_dock_new_launcher_icon
+#include "cairo-dock-separator-manager.h"  // cairo_dock_create_separator_surface
+#include "cairo-dock-X-utilities.h"  // cairo_dock_show_xwindow
 #include "cairo-dock-launcher-manager.h"
 
 extern CairoDock *g_pMainDock;
 extern gchar *g_cConfFile;
 extern gchar *g_cCurrentLaunchersPath;
-extern int g_iNbNonStickyLaunchers;
-
 
 static CairoDock *_cairo_dock_handle_container (Icon *icon, const gchar *cRendererName)
 {
@@ -101,22 +92,12 @@ static CairoDock *_cairo_dock_handle_container (Icon *icon, const gchar *cRender
 			cd_message ("le dock devient un dock fils (%d, %d)", pChildDock->container.bIsHorizontal, pChildDock->container.bDirectionUp);
 		}
 		if (cRendererName != NULL && icon->pSubDock != NULL)
+		{
 			cairo_dock_set_renderer (icon->pSubDock, cRendererName);
+			cairo_dock_update_dock_size (icon->pSubDock);
+		}
 	}
 	
-	//\____________ On met a jour les infos dans le cas d'un point de montage.
-	/*if (icon->iVolumeID)  // les infos dans le .desktop ne sont pas a jour.
-	{
-		g_free (icon->cName);
-		icon->cName = NULL;
-		g_free (icon->cCommand);
-		icon->cCommand = NULL;
-		g_free (icon->cFileName);
-		icon->cFileName = NULL;
-
-		gboolean bIsDirectory;  // on n'ecrase pas le fait que ce soit un container ou pas, car c'est l'utilisateur qui l'a decide.
-		cairo_dock_fm_get_file_info (icon->cBaseURI, &icon->cName, &icon->cCommand, &icon->cFileName, &bIsDirectory, &icon->iVolumeID, &icon->fOrder, CAIRO_DOCK_FM_SORT_BY_NAME);  // son ordre nous importe peu ici, puisqu'il est definie par le champ 'Order'.
-	}*/
 	return pParentDock;
 }
 
@@ -204,6 +185,12 @@ static gboolean _delete_launcher (Icon *icon)
 	return r;
 }
 
+static void _show_appli_for_drop (Icon *pIcon)
+{
+	if (pIcon->Xid != 0)
+		cairo_dock_show_xwindow (pIcon->Xid);
+}
+
 Icon * cairo_dock_create_icon_from_desktop_file (const gchar *cDesktopFileName)
 {
 	//g_print ("%s (%s)\n", __func__, cDesktopFileName);
@@ -222,6 +209,7 @@ Icon * cairo_dock_create_icon_from_desktop_file (const gchar *cDesktopFileName)
 	{
 		icon->iface.load_image = _load_launcher;
 		icon->iface.on_delete = _delete_launcher;
+		icon->iface.action_on_drag_hover = _show_appli_for_drop;
 	}
 	
 	//\____________ On gere son dock et sous-dock.
@@ -232,12 +220,9 @@ Icon * cairo_dock_create_icon_from_desktop_file (const gchar *cDesktopFileName)
 	cairo_dock_trigger_load_icon_buffers (icon, CAIRO_CONTAINER (pParentDock));
 	
 	cd_message ("+ %s/%s", icon->cName, icon->cClass);
-	if (CAIRO_DOCK_IS_NORMAL_LAUNCHER (icon) && icon->cClass != NULL)
+	if (icon->cClass != NULL)
 	{
-		if (myTaskBar.bMixLauncherAppli)
-			cairo_dock_inhibate_class (icon->cClass, icon);
-		else  // on l'insere quand meme dans la classe pour pouvoir ecraser l'icone X avec la sienne.
-			cairo_dock_add_inhibator_to_class (icon->cClass, icon);
+		cairo_dock_inhibite_class (icon->cClass, icon);  // gere le bMixLauncherAppli
 	}
 	
 	return icon;
@@ -248,9 +233,9 @@ Icon * cairo_dock_create_dummy_launcher (gchar *cName, gchar *cFileName, gchar *
 {
 	//\____________ On cree l'icone.
 	gchar *cRendererName = NULL;
-	Icon *pIcon = g_new0 (Icon, 1);
-	pIcon->iType = CAIRO_DOCK_LAUNCHER;
-	pIcon->iTrueType = CAIRO_DOCK_ICON_TYPE_LAUNCHER;
+	Icon *pIcon = cairo_dock_new_icon ();
+	pIcon->iTrueType = CAIRO_DOCK_ICON_TYPE_OTHER;
+	pIcon->iGroup = CAIRO_DOCK_LAUNCHER;
 	pIcon->cName = cName;
 	pIcon->cFileName = cFileName;
 	pIcon->cQuickInfo = cQuickInfo;
@@ -259,8 +244,7 @@ Icon * cairo_dock_create_dummy_launcher (gchar *cName, gchar *cFileName, gchar *
 	pIcon->fAlpha = 1.;
 	pIcon->fWidthFactor = 1.;
 	pIcon->fHeightFactor = 1.;
-	pIcon->cCommand = cCommand ? cCommand : g_strdup ("none");  /// virer le 'none' ...
-	///pIcon->cDesktopFileName = g_strdup ("none");
+	pIcon->cCommand = cCommand;
 	pIcon->iface.load_image = _load_launcher;
 	
 	return pIcon;
@@ -306,19 +290,18 @@ void cairo_dock_reload_launcher (Icon *icon)
 {
 	if (icon->cDesktopFileName == NULL || strcmp (icon->cDesktopFileName, "none") == 0)
 	{
-		cd_warning ("tried to reload a launcher whereas this icon (%s) is obviously not a launcher", icon->cName);
+		cd_warning ("missing config file for icon %s", icon->cName);
 		return ;
 	}
-	GError *erreur = NULL;
 	
 	//\_____________ On assure la coherence du nouveau fichier de conf.
-	if (CAIRO_DOCK_IS_LAUNCHER (icon))
+	if (CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (icon) || CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon))
 	{
 		gchar *cDesktopFilePath = g_strdup_printf ("%s/%s", g_cCurrentLaunchersPath, icon->cDesktopFileName);
 		GKeyFile* pKeyFile = cairo_dock_open_key_file (cDesktopFilePath);
 		g_return_if_fail (pKeyFile != NULL);
 		
-		if (icon->pSubDock != NULL)  // on assure l'unicite du nom du sous-dock ici, car cela n'est volontairement pas fait dans la fonction de creation de l'icone.
+		if (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon))  // on assure l'unicite du nom du sous-dock ici, car cela n'est volontairement pas fait dans la fonction de creation de l'icone.
 		{
 			gchar *cName = g_key_file_get_string (pKeyFile, "Desktop Entry", "Name", NULL);
 			if (cName == NULL || *cName == '\0')
@@ -330,35 +313,25 @@ void cairo_dock_reload_launcher (Icon *icon)
 				{
 					g_key_file_set_string (pKeyFile, "Desktop Entry", "Name", cUniqueName);
 					cairo_dock_write_keys_to_file (pKeyFile, cDesktopFilePath);
-					cd_debug ("on renomme a l'avance le sous-dock en %s\n", cUniqueName);
-					cairo_dock_rename_dock (icon->cName, icon->pSubDock, cUniqueName);  // on le renomme ici pour eviter de transvaser dans un nouveau dock (ca marche aussi ceci dit).
+					cd_debug ("on renomme a l'avance le sous-dock en %s", cUniqueName);
+					if (icon->pSubDock != NULL)
+						cairo_dock_rename_dock (icon->cName, icon->pSubDock, cUniqueName);  // on le renomme ici pour eviter de transvaser dans un nouveau dock (ca marche aussi ceci dit).
 				}
 				g_free (cUniqueName);
 			}
 			g_free (cName);
 		}
-		if (icon->cCommand != NULL)  // on assure que ca reste un lanceur.
+		if (CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (icon))  // pas vraiment utile mais bon.
 		{
 			gchar *cCommand = g_key_file_get_string (pKeyFile, "Desktop Entry", "Exec", NULL);
 			if (cCommand == NULL || *cCommand == '\0')
 			{
-				cCommand = g_strdup ("no command");
+				cCommand = g_strdup ("enter a command");
 				g_key_file_set_string (pKeyFile, "Desktop Entry", "Exec", cCommand);
 				cairo_dock_write_keys_to_file (pKeyFile, cDesktopFilePath);
 			}
 			g_free (cCommand);
 		}
-		/*if (icon->cBaseURI != NULL)  // on assure que ca reste un fichier.
-		{
-			gchar *cBaseURI = g_key_file_get_string (pKeyFile, "Desktop Entry", "Base URI", NULL);
-			if (cBaseURI == NULL || *cBaseURI == '\0')
-			{
-				cBaseURI = g_strdup (icon->cBaseURI);
-				g_key_file_set_string (pKeyFile, "Desktop Entry", "Base URI", cBaseURI);
-				cairo_dock_write_keys_to_file (pKeyFile, cDesktopFilePath);
-			}
-			g_free (cBaseURI);
-		}*/
 		
 		g_key_file_free (pKeyFile);
 		g_free (cDesktopFilePath);
@@ -370,12 +343,6 @@ void cairo_dock_reload_launcher (Icon *icon)
 	CairoDock *pDock = cairo_dock_search_dock_from_name (cPrevDockName);  // changement de l'ordre ou du container.
 	double fOrder = icon->fOrder;
 	
-	if (CAIRO_DOCK_IS_URI_LAUNCHER (icon) && icon->pSubDock != NULL)  // dans le cas d'un repertoire, beaucoup de parametres peuvent affecter le contenu du sous-dock : nombre de fichiers max, ordre, et meme l'URI. Donc on s'embete pas trop, on le recree.
-	{
-		cairo_dock_destroy_dock (icon->pSubDock, icon->cName);
-		icon->pSubDock = NULL;
-	}
-	
 	CairoDock *pSubDock = icon->pSubDock;
 	///icon->pSubDock = NULL;
 	gchar *cClass = icon->cClass;
@@ -415,7 +382,7 @@ void cairo_dock_reload_launcher (Icon *icon)
 		icon->cName = g_strdup (" ");
 	
 	if (cairo_dock_strings_differ (cName, icon->cName))
-		cairo_dock_load_icon_text (icon, &myLabels.iconTextDescription);
+		cairo_dock_load_icon_text (icon, &myIconsParam.iconTextDescription);
 	
 	//\_____________ On gere son sous-dock.
 	if (icon->Xid != 0)
@@ -430,13 +397,8 @@ void cairo_dock_reload_launcher (Icon *icon)
 		if (pSubDock != NULL && pSubDock != icon->pSubDock)  // ca n'est plus le meme container, on transvase ou on detruit.
 		{
 			cd_debug ("on transvase dans le nouveau sous-dock");
-			if (CAIRO_DOCK_IS_URI_LAUNCHER (icon))  // dans ce cas on ne transvase pas puisque le sous-dock est cree a partir du contenu du repertoire.
-				cairo_dock_destroy_dock (pSubDock, cName);
-			else
-			{
-				cairo_dock_remove_icons_from_dock (pSubDock, icon->pSubDock, icon->cName);
-				cairo_dock_destroy_dock (pSubDock, cName);
-			}
+			cairo_dock_remove_icons_from_dock (pSubDock, icon->pSubDock, icon->cName);
+			cairo_dock_destroy_dock (pSubDock, cName);
 			pSubDock = NULL;
 		}
 	}
@@ -456,10 +418,9 @@ void cairo_dock_reload_launcher (Icon *icon)
 		gchar *tmp = icon->cParentDockName;  // le detach_icon remet a 0 ce champ, il faut le donc conserver avant.
 		icon->cParentDockName = NULL;
 		cairo_dock_detach_icon_from_dock (icon, pDock, TRUE);
-		if (pDock->icons == NULL && pDock->iRefCount == 0 && ! pDock->bIsMainDock)  // on supprime les docks principaux vides.
+		if (pDock->icons == NULL && pDock->iRefCount == 0 && ! pDock->bIsMainDock)  // le dock devient vide, il se fera detruire automatiquement.
 		{
-			///cairo_dock_destroy_dock (pDock, cPrevDockName);
-			pDock = NULL;  // se fera detruire automatiquement.
+			pDock = NULL;
 		}
 		else
 		{
@@ -467,7 +428,8 @@ void cairo_dock_reload_launcher (Icon *icon)
 			cairo_dock_calculate_dock_icons (pDock);
 			gtk_widget_queue_draw (pDock->container.pWidget);
 		}
-		cairo_dock_insert_icon_in_dock (icon, pNewDock, CAIRO_DOCK_UPDATE_DOCK_SIZE, ! CAIRO_DOCK_ANIMATE_ICON);  // le remove et le insert vont declencher le redessin de l'icone pointant sur l'ancien et le nouveau sous-dock le cas echeant.
+		cairo_dock_insert_icon_in_dock (icon, pNewDock, CAIRO_DOCK_UPDATE_DOCK_SIZE, CAIRO_DOCK_ANIMATE_ICON);  // le remove et le insert vont declencher le redessin de l'icone pointant sur l'ancien et le nouveau sous-dock le cas echeant.
+		cairo_dock_launch_animation (CAIRO_CONTAINER (pNewDock));
 		icon->cParentDockName = tmp;
 	}
 	else  // le container est identique, on gere juste le changement d'ordre.
@@ -488,7 +450,7 @@ void cairo_dock_reload_launcher (Icon *icon)
 		{
 			cairo_dock_redraw_subdock_content (pNewDock);
 		}
-		cairo_dock_trigger_refresh_launcher_gui ();
+		///cairo_dock_trigger_refresh_launcher_gui ();  // a faire par l'app
 	}
 	
 	//\_____________ On gere l'inhibition de sa classe.
@@ -496,12 +458,12 @@ void cairo_dock_reload_launcher (Icon *icon)
 	if (cClass != NULL && (cNowClass == NULL || strcmp (cNowClass, cClass) != 0))  // la classe a change, on desinhibe l'ancienne.
 	{
 		icon->cClass = cClass;
-		cairo_dock_deinhibate_class (cClass, icon);
+		cairo_dock_deinhibite_class (cClass, icon);
 		cClass = NULL;  // libere par la fonction precedente.
 		icon->cClass = cNowClass;
 	}
-	if (myTaskBar.bMixLauncherAppli && cNowClass != NULL && (cClass == NULL || strcmp (cNowClass, cClass) != 0))  // la classe a change, on inhibe la nouvelle.
-		cairo_dock_inhibate_class (cNowClass, icon);
+	if (myTaskbarParam.bMixLauncherAppli && cNowClass != NULL && (cClass == NULL || strcmp (cNowClass, cClass) != 0))  // la classe a change, on inhibe la nouvelle.
+		cairo_dock_inhibite_class (cNowClass, icon);
 
 	//\_____________ On redessine les docks impactes.
 	cairo_dock_calculate_dock_icons (pNewDock);
