@@ -28,17 +28,23 @@
 #include <glib/gi18n.h>
 #include <curl/curl.h>
 
-#include "../config.h"
+#include "gldi-config.h"
 #include "cairo-dock-keyfile-utilities.h"
-//#include "cairo-dock-dock-manager.h"
-//#include "cairo-dock-gui-manager.h"
 #include "cairo-dock-task.h"
+#include "cairo-dock-config.h"
 #include "cairo-dock-log.h"
-#include "cairo-dock-internal-system.h"
+#include "cairo-dock-notifications.h"
+#define _MANAGER_DEF_
 #include "cairo-dock-packages.h"
 
-#define CAIRO_DOCK_DEFAULT_PACKAGES_LIST_FILE "list.conf"
+// public (manager, config, data)
+CairoConnectionParam myConnectionParam;
+CairoConnectionManager myConnectionMgr;
 
+// dependancies
+
+// private
+#define CAIRO_DOCK_DEFAULT_PACKAGES_LIST_FILE "list.conf"
 static gchar *s_cPackageServerAdress = NULL;
 
   ////////////////////
@@ -118,28 +124,30 @@ static inline CURL *_init_curl_connection (const gchar *cURL)
 {
 	CURL *handle = curl_easy_init ();
 	curl_easy_setopt (handle, CURLOPT_URL, cURL);
-	if (mySystem.cConnectionProxy != NULL)
+	if (myConnectionParam.cConnectionProxy != NULL)
 	{
-		curl_easy_setopt (handle, CURLOPT_PROXY, mySystem.cConnectionProxy);
-		if (mySystem.iConnectionPort != 0)
-			curl_easy_setopt (handle, CURLOPT_PROXYPORT, mySystem.iConnectionPort);
-		if (mySystem.cConnectionUser != NULL && mySystem.
+		curl_easy_setopt (handle, CURLOPT_PROXY, myConnectionParam.cConnectionProxy);
+		if (myConnectionParam.iConnectionPort != 0)
+			curl_easy_setopt (handle, CURLOPT_PROXYPORT, myConnectionParam.iConnectionPort);
+		if (myConnectionParam.cConnectionUser != NULL && myConnectionParam.
 			cConnectionPasswd != NULL)
 		{
-			gchar *cUserPwd = g_strdup_printf ("%s:%s", mySystem.cConnectionUser, mySystem.
+			gchar *cUserPwd = g_strdup_printf ("%s:%s", myConnectionParam.cConnectionUser, myConnectionParam.
 			cConnectionPasswd);
 			curl_easy_setopt (handle, CURLOPT_PROXYUSERPWD, cUserPwd);
 			g_free (cUserPwd);
-			/*curl_easy_setopt (handle, CURLOPT_PROXYUSERNAME, mySystem.cConnectionUser);
-			if (mySystem.cConnectionPasswd != NULL)
-				curl_easy_setopt (handle, CURLOPT_PROXYPASSWORD, mySystem.cConnectionPasswd);*/  // a partir de libcurl 7.19.1, donc apres Jaunty
+			/*curl_easy_setopt (handle, CURLOPT_PROXYUSERNAME, myConnectionParam.cConnectionUser);
+			if (myConnectionParam.cConnectionPasswd != NULL)
+				curl_easy_setopt (handle, CURLOPT_PROXYPASSWORD, myConnectionParam.cConnectionPasswd);*/  // a partir de libcurl 7.19.1, donc apres Jaunty
 		}
 	}
-	if (mySystem.bForceIPv4)
+	if (myConnectionParam.bForceIPv4)
 		curl_easy_setopt (handle, CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V4);  // la resolution d'adresse en ipv6 peut etre tres lente chez certains.
-	curl_easy_setopt (handle, CURLOPT_TIMEOUT, mySystem.iConnectionMaxTime);
-	curl_easy_setopt (handle, CURLOPT_CONNECTTIMEOUT, mySystem.iConnectionTimeout);
+	curl_easy_setopt (handle, CURLOPT_TIMEOUT, myConnectionParam.iConnectionMaxTime);
+	curl_easy_setopt (handle, CURLOPT_CONNECTTIMEOUT, myConnectionParam.iConnectionTimeout);
 	curl_easy_setopt (handle, CURLOPT_NOSIGNAL, 1);  // With CURLOPT_NOSIGNAL set non-zero, curl will not use any signals; sinon curl se vautre apres le timeout, meme si le download s'est bien passe !
+	curl_easy_setopt (handle, CURLOPT_FOLLOWLOCATION , 1);  // follow redirection
+	curl_easy_setopt (handle, CURLOPT_USERAGENT , "a/5.0 (X11; Linux x86_64; rv:2.0b11) Gecko/20100101 Firefox/4.0b11");
 	return handle;
 }
 
@@ -271,11 +279,43 @@ static size_t _write_data_to_buffer (gpointer buffer, size_t size, size_t nmemb,
 	*list_ptr = g_list_prepend (*list_ptr, g_strndup (buffer, size * nmemb));
 	return size * nmemb;
 }
-gchar *cairo_dock_get_url_data (const gchar *cURL, GError **erreur)
+
+gchar *cairo_dock_get_url_data_with_post (const gchar *cURL, gboolean bGetOutputHeaders, GError **erreur, const gchar *cFirstProperty, ...)
 {
 	//\_______________ On lance le download.
 	cd_debug ("getting data from '%s' ...", cURL);
 	CURL *handle = _init_curl_connection (cURL);
+	
+	GString *sPostData = NULL;
+	if (cFirstProperty != NULL)
+	{
+		sPostData = g_string_new ("");
+		const gchar *cProperty = cFirstProperty;
+		gchar *cData;
+		gchar *cEncodedData = NULL;
+		va_list args;
+		va_start (args, cFirstProperty);
+		do
+		{
+			cData = va_arg (args, gchar *);
+			if (!cData)
+				break;
+				if (cEncodedData != NULL)  // we don't access the pointer, we just want to know if we have already looped once or not.
+				g_string_append_c (sPostData, '&');
+			cEncodedData = curl_easy_escape (handle, cData, 0);
+			g_string_append_printf (sPostData, "%s=%s", cProperty, cEncodedData);
+			curl_free (cEncodedData);
+			cProperty = va_arg (args, gchar *);
+		}
+		while (cProperty != NULL);
+		va_end (args);
+		// g_print ("POST data: '%s'\n", sPostData->str);
+		
+		curl_easy_setopt (handle, CURLOPT_POST, 1);
+		curl_easy_setopt (handle, CURLOPT_POSTFIELDS, sPostData->str);
+		if (bGetOutputHeaders)
+			curl_easy_setopt (handle, CURLOPT_HEADER, 1);
+	}
 	curl_easy_setopt (handle, CURLOPT_WRITEFUNCTION, (curl_write_callback)_write_data_to_buffer);
 	gpointer *pointer_to_list = g_new0 (gpointer, 1);
 	curl_easy_setopt (handle, CURLOPT_WRITEDATA, pointer_to_list);
@@ -290,6 +330,8 @@ gchar *cairo_dock_get_url_data (const gchar *cURL, GError **erreur)
 	}
 	
 	curl_easy_cleanup (handle);
+	if (sPostData)
+		g_string_free (sPostData, TRUE);
 	
 	//\_______________ On recupere les donnees.
 	gchar *cContent = NULL;
@@ -468,7 +510,7 @@ static void _cairo_dock_parse_package_list (GKeyFile *pKeyFile, const gchar *cSe
 	g_return_if_fail (pGroupList != NULL);  // rien a charger dans la table, on quitte.
 	
 	// on parcourt la liste.
-	gchar *cPackageName, *cDate, *cDisplayedName, *cName, *cAuthor;
+	gchar *cPackageName, *cName, *cAuthor;
 	CairoDockPackage *pPackage;
 	CairoDockPackageType iType;
 	double fSize;
@@ -489,10 +531,11 @@ static void _cairo_dock_parse_package_list (GKeyFile *pKeyFile, const gchar *cSe
 			g_free (cAuthor);
 			cAuthor = NULL;
 		}
-		cName = NULL;
-		if (g_key_file_has_key (pKeyFile, cPackageName, "name", NULL))
+		cName = g_key_file_get_string (pKeyFile, cPackageName, "name", NULL);
+		if (cName && *cName == '\0')
 		{
-			cName = g_key_file_get_string (pKeyFile, cPackageName, "name", NULL);
+			g_free (cName);
+			cName = NULL;
 		}
 		
 		// creation < 30j && pas sur le disque -> new
@@ -520,7 +563,7 @@ static void _cairo_dock_parse_package_list (GKeyFile *pKeyFile, const gchar *cSe
 					iLocalDate = day + (month - 1) * 1e2 + year * 1e4;
 				else
 					iLocalDate = day + 12 * 1e2 + (year - 1) * 1e4;
-				cDate = g_strdup_printf ("%d", iLocalDate);
+				gchar *cDate = g_strdup_printf ("%d", iLocalDate);
 				g_file_set_contents (cVersionFile,
 					cDate,
 					-1,
@@ -541,9 +584,8 @@ static void _cairo_dock_parse_package_list (GKeyFile *pKeyFile, const gchar *cSe
 			{
 				pSamePackage->iSobriety = iSobriety;  // par contre on en profite pour renseigner la sobriete.
 				g_free (pSamePackage->cDisplayedName);
-				pSamePackage->cDisplayedName = g_strdup_printf ("%s by %s", cName ? cName : cPackageName, (cAuthor ? cAuthor : "---"));
-				pSamePackage->cAuthor = cAuthor;
-				g_free (cName);
+				pSamePackage->cDisplayedName = (cName ? cName : g_strdup (cPackageName));
+				pSamePackage->cAuthor = cAuthor;  // et l'auteur original.
 				g_free (cPackageName);
 				continue;
 			}
@@ -566,7 +608,7 @@ static void _cairo_dock_parse_package_list (GKeyFile *pKeyFile, const gchar *cSe
 				iType = CAIRO_DOCK_DISTANT_PACKAGE;
 			
 			pPackage = g_new0 (CairoDockPackage, 1);
-			g_hash_table_insert (pPackageTable, cPackageName, pPackage);
+			g_hash_table_insert (pPackageTable, g_strdup (cPackageName), pPackage);
 			pPackage->iRating = g_key_file_get_integer (pKeyFile, cPackageName, "rating", NULL);  // par contre on affiche la note que l'utilisateur avait precedemment etablie.
 		}
 		
@@ -574,13 +616,14 @@ static void _cairo_dock_parse_package_list (GKeyFile *pKeyFile, const gchar *cSe
 		pPackage->iType = iType;
 		pPackage->fSize = fSize;
 		pPackage->cAuthor = cAuthor;
-		pPackage->cDisplayedName = g_strdup_printf ("%s by %s [%.2f MB]", cName ? cName : cPackageName, (cAuthor ? cAuthor : "---"), fSize);
+		pPackage->cDisplayedName = (cName ? cName : g_strdup (cPackageName));
 		pPackage->iSobriety = iSobriety;
 		pPackage->iCategory = iCategory;
 		pPackage->iCreationDate = iCreationDate;
 		pPackage->iLastModifDate = iLastModifDate;
+		g_free (cPackageName);
 	}
-	g_free (pGroupList);  // les noms des packages sont desormais dans la hash-table.
+	g_free (pGroupList);  // les noms des packages sont liberes dans la boucle.
 }
 GHashTable *cairo_dock_list_net_packages (const gchar *cServerAdress, const gchar *cDirectory, const gchar *cListFileName, GHashTable *hProvidedTable, GError **erreur)
 {
@@ -632,11 +675,11 @@ GHashTable *cairo_dock_list_net_packages (const gchar *cServerAdress, const gcha
 	return pPackageTable;
 }
 
-GHashTable *cairo_dock_list_packages (const gchar *cSharePackagesDir, const gchar *cUserPackagesDir, const gchar *cDistantPackagesDir)
+GHashTable *cairo_dock_list_packages (const gchar *cSharePackagesDir, const gchar *cUserPackagesDir, const gchar *cDistantPackagesDir, GHashTable *pTable)
 {
 	cd_message ("%s (%s, %s, %s)", __func__, cSharePackagesDir, cUserPackagesDir, cDistantPackagesDir);
 	GError *erreur = NULL;
-	GHashTable *pPackageTable = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) cairo_dock_free_package);
+	GHashTable *pPackageTable = (pTable ? pTable : g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) cairo_dock_free_package));
 	
 	//\______________ On recupere les packages pre-installes.
 	if (cSharePackagesDir != NULL)
@@ -675,7 +718,7 @@ GHashTable *cairo_dock_list_packages (const gchar *cSharePackagesDir, const gcha
 
 static void _list_packages (gpointer *pSharedMemory)
 {
-	pSharedMemory[5] = cairo_dock_list_packages (pSharedMemory[0], pSharedMemory[1], pSharedMemory[2]);
+	pSharedMemory[5] = cairo_dock_list_packages (pSharedMemory[0], pSharedMemory[1], pSharedMemory[2], pSharedMemory[5]);
 }
 static gboolean _finish_list_packages (gpointer *pSharedMemory)
 {
@@ -695,7 +738,7 @@ static void _discard_list_packages (gpointer *pSharedMemory)
 		g_hash_table_unref (pSharedMemory[5]);
 	g_free (pSharedMemory);
 }
-CairoDockTask *cairo_dock_list_packages_async (const gchar *cSharePackagesDir, const gchar *cUserPackagesDir, const gchar *cDistantPackagesDir, CairoDockGetPackagesFunc pCallback, gpointer data)
+CairoDockTask *cairo_dock_list_packages_async (const gchar *cSharePackagesDir, const gchar *cUserPackagesDir, const gchar *cDistantPackagesDir, CairoDockGetPackagesFunc pCallback, gpointer data, GHashTable *pTable)
 {
 	gpointer *pSharedMemory = g_new0 (gpointer, 6);
 	pSharedMemory[0] = g_strdup (cSharePackagesDir);
@@ -703,6 +746,7 @@ CairoDockTask *cairo_dock_list_packages_async (const gchar *cSharePackagesDir, c
 	pSharedMemory[2] = g_strdup (cDistantPackagesDir);
 	pSharedMemory[3] = pCallback;
 	pSharedMemory[4] = data;
+	pSharedMemory[5] = pTable;  // can be NULL
 	CairoDockTask *pTask = cairo_dock_new_task_full (0, (CairoDockGetDataAsyncFunc) _list_packages, (CairoDockUpdateSyncFunc) _finish_list_packages, (GFreeFunc) _discard_list_packages, pSharedMemory);
 	cairo_dock_launch_task (pTask);
 	return pTask;
@@ -792,17 +836,87 @@ CairoDockPackageType cairo_dock_extract_package_type_from_name (const gchar *cPa
 	return iType;
 }
 
-#define _check_dir(cDirPath) \
-	if (! g_file_test (cDirPath, G_FILE_TEST_IS_DIR)) {\
-		if (g_mkdir (cDirPath, 7*8*8+7*8+7) != 0) {\
-			cd_warning ("couldn't create directory %s", cDirPath);\
-			g_free (cDirPath);\
-			cDirPath = NULL; } }
 
 void cairo_dock_init_package_manager (gchar *cPackageServerAdress)
 {
 	s_cPackageServerAdress = cPackageServerAdress;
 	
 	//\___________________ On initialise le gestionnaire de download.
+	curl_global_init (CURL_GLOBAL_DEFAULT);  /// merge with init
+}
+
+
+  //////////////////
+ /// GET CONFIG ///
+//////////////////
+
+static gboolean get_config (GKeyFile *pKeyFile, CairoConnectionParam *pSystem)
+{
+	gboolean bFlushConfFileNeeded = FALSE;
+	
+	pSystem->iConnectionTimeout = cairo_dock_get_integer_key_value (pKeyFile, "System", "conn timeout", &bFlushConfFileNeeded, 7, NULL, NULL);
+	pSystem->iConnectionMaxTime = cairo_dock_get_integer_key_value (pKeyFile, "System", "conn max time", &bFlushConfFileNeeded, 120, NULL, NULL);
+	if (cairo_dock_get_boolean_key_value (pKeyFile, "System", "conn use proxy", &bFlushConfFileNeeded, FALSE, NULL, NULL))
+	{
+		pSystem->cConnectionProxy = cairo_dock_get_string_key_value (pKeyFile, "System", "conn proxy", &bFlushConfFileNeeded, NULL, NULL, NULL);
+		pSystem->iConnectionPort = cairo_dock_get_integer_key_value (pKeyFile, "System", "conn port", &bFlushConfFileNeeded, 0, NULL, NULL);
+		pSystem->cConnectionUser = cairo_dock_get_string_key_value (pKeyFile, "System", "conn user", &bFlushConfFileNeeded, NULL, NULL, NULL);
+		gchar *cPasswd = cairo_dock_get_string_key_value (pKeyFile, "System", "conn passwd", &bFlushConfFileNeeded, NULL, NULL, NULL);
+		cairo_dock_decrypt_string (cPasswd, &pSystem->cConnectionPasswd);
+		pSystem->bForceIPv4 = cairo_dock_get_boolean_key_value (pKeyFile, "System", "force ipv4", &bFlushConfFileNeeded, TRUE, NULL, NULL);
+	}
+	
+	return bFlushConfFileNeeded;
+}
+
+  ////////////////////
+ /// RESET CONFIG ///
+////////////////////
+
+static void reset_config (CairoConnectionParam *pSystem)
+{
+	g_free (pSystem->cConnectionProxy);
+	g_free (pSystem->cConnectionUser);
+	g_free (pSystem->cConnectionPasswd);
+}
+
+
+  ////////////
+ /// INIT ///
+////////////
+
+static void init (void)
+{
 	curl_global_init (CURL_GLOBAL_DEFAULT);
 }
+
+
+  ///////////////
+ /// MANAGER ///
+///////////////
+
+void gldi_register_connection_manager (void)
+{
+	// Manager
+	memset (&myConnectionMgr, 0, sizeof (CairoConnectionManager));
+	myConnectionMgr.mgr.cModuleName 	= "Connection";
+	myConnectionMgr.mgr.init 		= init;
+	myConnectionMgr.mgr.load 		= NULL;
+	myConnectionMgr.mgr.unload 		= NULL;
+	myConnectionMgr.mgr.reload 		= (GldiManagerReloadFunc)NULL;
+	myConnectionMgr.mgr.get_config 	= (GldiManagerGetConfigFunc)get_config;
+	myConnectionMgr.mgr.reset_config = (GldiManagerResetConfigFunc)reset_config;
+	// Config
+	myConnectionMgr.mgr.pConfig = (GldiManagerConfigPtr*)&myConnectionParam;
+	myConnectionMgr.mgr.iSizeOfConfig = sizeof (CairoConnectionParam);
+	// data
+	myConnectionMgr.mgr.pData = (GldiManagerDataPtr*)NULL;
+	myConnectionMgr.mgr.iSizeOfData = 0;
+	// signals
+	cairo_dock_install_notifications_on_object (&myConnectionMgr, NB_NOTIFICATIONS_CONNECTION);
+	// register
+	gldi_register_manager (GLDI_MANAGER(&myConnectionMgr));
+}
+
+
+
