@@ -28,16 +28,16 @@
 #include <cairo-glitz.h>
 #endif
 
-#include "cairo-dock-icons.h"
+#include "cairo-dock-icon-factory.h"
 #include "cairo-dock-separator-factory.h"
 
 
 Icon *cairo_dock_new_separator_icon (int iSeparatorType)
 {
 	//\____________ On cree l'icone.
-	Icon *icon = g_new0 (Icon, 1);
-	icon->iType = iSeparatorType;
+	Icon *icon = cairo_dock_new_icon ();
 	icon->iTrueType = CAIRO_DOCK_ICON_TYPE_SEPARATOR;
+	icon->iGroup = iSeparatorType;
 	
 	return icon;
 }
